@@ -24,6 +24,7 @@
 #include <locale.h>
 #include "utf8.hh"
 #include "drawablecont.hh"
+#include "popupwindow.hh"
 #include <algorithm>
 
 #ifdef USE_AGUIXTIMER
@@ -116,14 +117,15 @@ void aguix_timer( int s )
 }
 #endif
 
-AGUIX::AGUIX()
+AGUIX::AGUIX( int argc, char **argv, const std::string &classname ) : m_argc( argc ),
+                                                                      m_argv( argv ),
+                                                                      m_classname( classname )
 {
 #ifdef USE_AGUIXTIMER
   struct sigaction sig_ac;
 #endif
 
   initOK=False;
-  classname=NULL;
   mainfont=NULL;
   dsp=NULL;
   colors=0;
@@ -151,9 +153,11 @@ AGUIX::AGUIX()
   sig_ac.sa_handler = aguix_timer;
   sigaction( SIGALRM, &sig_ac, NULL );
 #endif
+
+  m_open_popup_counter = 0;
 }
   
-int AGUIX::initX( int targc, char **targv, const char *tclassname )
+int AGUIX::initX()
 {
   debugmsg("Opening display...");
 
@@ -178,7 +182,6 @@ int AGUIX::initX( int targc, char **targv, const char *tclassname )
 
   UTF8::checkSupportedEncodings();
 
-  this->classname=dupstring(tclassname);
   scr=XDefaultScreen(dsp);
   cmap=DefaultColormap(dsp,scr);
   white=WhitePixel(dsp,scr);
@@ -231,8 +234,6 @@ int AGUIX::initX( int targc, char **targv, const char *tclassname )
   XChangeGC( dsp, dashdouble_gc, GCLineStyle | GCBackground | GCForeground, &gc_values );
 
   WM_delete_window=XInternAtom(dsp,"WM_DELETE_WINDOW",False);
-  this->argc=targc;
-  this->argv=targv;
   createGroupWin();
 
   cursors[WAIT_CURSOR]=XCreateFontCursor(dsp,XC_watch);
@@ -285,7 +286,6 @@ void AGUIX::closeX()
       fonts.pop_front();
       delete tf;
   }
-  if(classname!=NULL) _freesafe(classname);
 
   while ( colors > 0 ) {
     removeLastColor();
@@ -489,11 +489,9 @@ int AGUIX::getMaxCols() const
   return colors;
 }
 
-char *AGUIX::getClassname() const
+std::string AGUIX::getClassname() const
 {
-  char *tstr;
-  tstr=dupstring(classname);
-  return tstr;
+    return m_classname;
 }
 
 unsigned long AGUIX::getPixel( int color ) const
@@ -541,6 +539,12 @@ void AGUIX::insertWindow(AWindow *win)
 void AGUIX::removeWindow(AWindow *win)
 {
   if(win==NULL) return;
+
+  PopUpWindow *popwin = dynamic_cast<PopUpWindow*>( win );
+  if ( popwin != NULL ) {
+      popup_wins.remove( popwin );
+  }
+
   wins.remove( win );
   if ( win == transientwindow ) {
     AWindow *new_transient_win = NULL;
@@ -855,6 +859,9 @@ int AGUIX::msgHandler( int mode, AWindow *parent, bool onlyExpose )
       } else if ( tmsg->type == KeyRelease ) {
 	lastkeyrelease = tmsg->key;
       }
+
+      checkPopUpWindows( tmsg );
+      
       AGUIX_freeMessage( tmsg );
     }
 
@@ -968,17 +975,23 @@ bool AGUIX::ReactMessage(Message *msg,AWindow *parent)
        ( msg->specialType == Message::NONE ) ) {
     return returnvalue;
   }
+  
+  bool popup_opened = ( m_open_popup_counter > 0 );
+  
   while ( msg->loop < 2 ) {
       for ( wins_cit_t it1 = wins.begin();
             ( it1 != wins.end() ) && ( returnvalue == false );
             it1++ ) {
           AWindow *win = *it1;
-          if ( ( parent == NULL ) || ( msg->type == Expose ) ) {
+
+          if ( msg->type == Expose ) {
               returnvalue = win->handleMessage( &LastEvent, msg );
-          } else {
-              if ( parent->isParent( win->getWindow(), false ) == true ) {
+          } else if ( m_open_popup_counter > 0 ) {
+              if ( dynamic_cast<PopUpWindow*>( win ) != NULL ) {
                   returnvalue = win->handleMessage( &LastEvent, msg );
               }
+          } else if ( parent == NULL || parent->isParent( win->getWindow(), false ) == true ) {
+              returnvalue = win->handleMessage( &LastEvent, msg );
           }
           // with lockElement don't quit this loop
           if ( msg->lockElement != NULL ) returnvalue = false;
@@ -1004,6 +1017,13 @@ bool AGUIX::ReactMessage(Message *msg,AWindow *parent)
     }
     msg->loop++;
   }
+  
+  if ( popup_opened == true ) {
+      // if there was (or is) a popup opened always
+      // return true so we don't create AGMessages
+      // (especially for key events)
+      return true;
+  }
   return returnvalue;
 }
 
@@ -1014,12 +1034,12 @@ void AGUIX::Flush()
 
 int AGUIX::getargc() const
 {
-  return argc;
+  return m_argc;
 }
 
 char **AGUIX::getargv() const
 {
-  return argv;
+  return m_argv;
 }
 
 void AGUIX::putAGMsg(AGMessage *msg)
@@ -1206,7 +1226,7 @@ void AGUIX::createGroupWin()
     return;
   }
   XClassHint classhint;
-  tstr=getClassname();
+  tstr = dupstring( getClassname().c_str() );
   classhint.res_name=tstr;
   classhint.res_class=tstr;
   XSetClassHint(dsp,groupwin,&classhint);
@@ -2147,12 +2167,12 @@ unsigned int AGUIX::getLastMouseRelease()
   return m;
 }
 
-void AGUIX::msgLock( GUIElement *e )
+void AGUIX::msgLock( Widget *e )
 {
   msgLockElement = e;
 }
 
-void AGUIX::msgUnlock( const GUIElement *e )
+void AGUIX::msgUnlock( const Widget *e )
 {
   if ( msgLockElement != e ) {
     fprintf( stderr, "Worker:wrong msgUnlock\n" );
@@ -2160,6 +2180,13 @@ void AGUIX::msgUnlock( const GUIElement *e )
   msgLockElement = NULL;
 }
 
+bool AGUIX::msgHoldsLock( const Widget *e )
+{
+    if ( msgLockElement == e )
+        return true;
+    return false;
+}
+
 void AGUIX::enableTimer()
 {
 #ifdef USE_AGUIXTIMER
@@ -2570,3 +2597,108 @@ int AGUIX::getColorForName( const std::string &name )
         return -1;
     return _colors_for_widgets[name];
 }
+
+void AGUIX::registerPopUpWindow( PopUpWindow *win )
+{
+    if ( win == NULL ) return;
+
+    popup_wins.push_back( win );
+}
+
+void AGUIX::checkPopUpWindows( Message *msg )
+{
+    if ( msg == NULL ) return;
+
+    if ( m_open_popup_counter < 1 ) return;
+    if ( msg->type != ButtonPress && msg->type != ButtonRelease ) return;
+
+    // check whether the event window is owned by some of the registered popups
+    //  if there is a popup, get its groupid and close all other popups
+    //  if not, close all popups
+
+    PopUpWindow *win_for_msg = NULL;
+
+    for ( popup_wins_cit_t it1 = popup_wins.begin();
+          it1 != popup_wins.end();
+          it1++ ) {
+        if ( (*it1)->isParent( msg->window ) == true ) {
+            win_for_msg = *it1;
+            break;
+        }
+    }
+
+    if ( win_for_msg == NULL ) {
+        // not a message for a popup window
+        // so hide all popups
+        for ( popup_wins_cit_t it1 = popup_wins.begin();
+              it1 != popup_wins.end();
+              it1++ ) {
+            (*it1)->hide();
+        }
+    } else {
+        // found a popup window for the message
+        // so hide all popups which are not in the same group
+        hideOtherPopUpWindows( win_for_msg->getGroupID() );
+    }
+}
+
+void AGUIX::hidePopUpWindows( int group_id )
+{
+    for ( popup_wins_cit_t it1 = popup_wins.begin();
+          it1 != popup_wins.end();
+          it1++ ) {
+        if ( (*it1)->getGroupID() == group_id ) {
+            (*it1)->hide();
+        }
+    }
+}
+
+void AGUIX::hideOtherPopUpWindows( int group_id )
+{
+    for ( popup_wins_cit_t it1 = popup_wins.begin();
+          it1 != popup_wins.end();
+          it1++ ) {
+        if ( (*it1)->getGroupID() != group_id ) {
+            (*it1)->hide();
+        }
+    }
+}
+
+void AGUIX::xSync()
+{
+    XSync( dsp, False );
+}
+
+void AGUIX::popup_opened()
+{
+    m_open_popup_counter++;
+}
+
+void AGUIX::popup_closed()
+{
+    m_open_popup_counter--;
+    if ( m_open_popup_counter < 0 ) {
+        fprintf( stderr, "Worker:bug in popup counter\n" );
+        m_open_popup_counter = 0;
+    }
+}
+
+int AGUIX::getWidgetRootPosition( Widget *widget, int *x, int *y )
+{
+    if ( widget == NULL || x == NULL || y == NULL ) return 1;
+    
+    int tx, tx2, ty, ty2;
+    
+    //TODO this is a rather ugly hack, better walk through window hierarchy with
+    // XQueryTree and querying the corresponding postions
+    queryPointer( widget->getWindow(), &tx, &ty );
+    queryRootPointer( &tx2, &ty2 );
+    
+    tx2 -= tx;
+    ty2 -= ty;
+    
+    *x = tx2;
+    *y = ty2;
+    
+    return 0;
+}
