@@ -1,6 +1,6 @@
 /* awindow.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: awindow.cc,v 1.61 2005/12/01 21:13:43 ralf Exp $ */
 
 #include "awindow.h"
 #include "text.h"
@@ -175,15 +174,12 @@ void AWindow::setMinSize(int mwidth,int mheight)
 
 void AWindow::show()
 {
-  int cnr;
-
   if(onScreen==true) return;
   Display *dsp=_aguix->getDisplay();
 
-  cnr = getMapNr();
   XMapWindow(dsp,win);
   onScreen=true;
-  while ( getMapNr() == cnr ) _aguix->doXMsgs( MES_WAIT, NULL, false );
+  _aguix->xSync();
 }
 
 void AWindow::hide()
@@ -307,9 +303,9 @@ bool AWindow::handleMessage(XEvent *E,Message *msg)
   res = 0;
   for ( childs_it it1 = _childs.begin(); it1 != _childs.end(); it1++ ) {
     //TODO Original wurden nur den GUIElement eine msg geschickt,
-    //     man knnte aber auch den AWindows die Msg weitergeben
-    //     und in AGUIX nur noch Toplevel anstoen
-    //     Es knnte aber Probleme machen, wenn ich bei
+    //     man koennte aber auch den AWindows die Msg weitergeben
+    //     und in AGUIX nur noch Toplevel anstossen
+    //     Es koennte aber Probleme machen, wenn ich bei
     //     res == 1 abbreche
     guielem = dynamic_cast<GUIElement*>( (*it1) );
     if ( guielem != NULL ) {
@@ -347,7 +343,7 @@ bool AWindow::handleMessage(XEvent *E,Message *msg)
     AGMessage *agmsg = AGUIX_allocAGMessage( msg );
     
     for ( it = key_listener.begin(); it != key_listener.end(); it++ ) {
-      //TODO pruefen, ob subwin berhautp ein subwin von this is, also recursiv alle childs pruefen
+      //TODO pruefen, ob subwin ue1berhautp ein subwin von this is, also recursiv alle childs pruefen
       if ( ( (*it).mode & KEYCB_WHENVISIBLE ) == 0 || (*it).subwin->isVisible() == true ) {
         forbidCallBacks();
         (*it).cb->run( (*it).subwin, *agmsg );
@@ -1135,8 +1131,8 @@ int AWindow::setParent( class AWindow *parent )
   //TODO it would be possible to destroy the window in
   // this case and reopen it
   if ( _created == true ) return 1;
-  //TODO Wenn das Fenster schon ein Fokuselement hlt,
-  //     Dann sollte es dem parent bergeben werden
+  //TODO Wenn das Fenster schon ein Fokuselement haelt,
+  //     Dann sollte es dem parent uebergeben werden
   return Widget::setParent( parent );
 }
 
@@ -1151,7 +1147,7 @@ int AWindow::setWMTitle()
   if ( ( dsp == NULL ) || ( win == 0 ) ) return 1;
   
   classhint.res_name = dupstring( _title.c_str() );
-  classhint.res_class = _aguix->getClassname();
+  classhint.res_class = dupstring( _aguix->getClassname().c_str() );
   XSetClassHint( dsp, win, &classhint );
   _freesafe( classhint.res_class );
   _freesafe( classhint.res_name );
