@@ -1,6 +1,6 @@
 /* awindow.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -29,6 +29,7 @@
 #include "text.h"
 #include "request.h"
 #include "acontainer.h"
+#include "callback.h"
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -58,9 +59,9 @@ public:
   int setResizable(int state);
   void setMaxSize(int mwidth,int mheight);
   void setMinSize(int mwidth,int mheight);
-  void show();
+  virtual void show();
   void show(Window);
-  void hide();
+  virtual void hide();
   void hide(Window);
   void minimize();
   void toFront();
@@ -101,6 +102,11 @@ public:
 			 Text ***return_texts,
 			 int *return_count,
 			 int *return_y );
+  int addMultiLineText( const std::string text,
+                        AContainer &ac,
+                        int xpos, int ypos,
+                        AContainer **return_container,
+                        std::list<Text*> *return_text_list );
   void centerScreen();
   bool contains( Widget *elem ) const;
   Widget *getFocusOwner() const;
@@ -144,6 +150,20 @@ public:
   int create();
 
   int addWindowEvent( Window subwin, long mask );
+
+  int getMinWidth() const;
+  int getMinHeight() const;
+  int getMaxWidth() const;
+  int getMaxHeight() const;
+
+  static const int KEYCB_WHENVISIBLE = 1;
+
+  void addKeyCallBack( CallBack *new_cb, int mode = 0 );
+  void removeKeyCallBack( CallBack *cb );
+
+  void forbidCallBacks();
+  void permitCallBacks();
+  bool callBackForbidden() const;
 protected:
   bool onScreen;
   int _bg;
@@ -182,6 +202,18 @@ private:
   typedef std::list<Widget*>::iterator childs_it;
   typedef std::list<Widget*>::const_iterator childs_const_it;
   std::string _title;
+
+  typedef struct {
+    CallBack *cb;
+    AWindow *subwin;
+    int mode;
+  } key_listener_t;
+  std::list<key_listener_t> key_listener;
+
+  void addKeyCallBack( AWindow *subwin, CallBack *new_cb, int mode = 0 );
+  void removeKeyCallBack( AWindow *subwin, CallBack *cb );
+
+  bool _callback_forbidden;
 };
 
 #endif
