@@ -23,6 +23,7 @@
 #include "button.h"
 #include "awindow.h"
 #include "guielement.h"
+#include "drawablecont.hh"
 
 const char *Button::type="Button";
 
@@ -128,7 +129,7 @@ Button::Button(AGUIX *taguix,int tx,int ty,int width,
 const char *Button::getText(int index2) const
 {
   if((index2<0)||(index2>1)) return NULL;
-  return dupstring(text[index2]);
+  return text[index2];
 }
 
 void Button::setText(int index2,const char *new_text)
@@ -192,7 +193,6 @@ void Button::setData(int tdata)
 
 void Button::redraw()
 {
-  GC usegc;
   bool showe=false;
   int px1 = 0,
       py1 = 0,
@@ -207,6 +207,7 @@ void Button::redraw()
   int len, strwidth;
   unsigned int ear_width = 0 ;
   int bw;
+  int text_color;
 
   if ( isCreated() == false ) return;
   if ( win == 0 ) return;
@@ -217,8 +218,6 @@ void Button::redraw()
   /* Clear the window */
   _aguix->ClearWin(win);
   
-  if(font==NULL) usegc=0; else usegc=font->getGC();
-
   /* calculate dimension of the turned-down corner */
 
   if ( ( dual == true ) && ( showdual == true ) && ( state != 2 ) ) {
@@ -241,9 +240,9 @@ void Button::redraw()
   /* draw the text */
 
   if ( ( dual == false ) || ( state != 2 ) ) {
-    _aguix->setFG(usegc,fg[0]);
+    text_color = fg[0];
   } else {
-    _aguix->setFG(usegc,fg[1]);
+    text_color = fg[1];
   }
   if(font==NULL) {
     ch=_aguix->getCharHeight();
@@ -268,11 +267,8 @@ void Button::redraw()
 
     int dx = _w / 2 - strwidth / 2;
     
-    if ( font == NULL ) {
-      _aguix->DrawText( win, tstr, dx, dy );
-    } else {
-      _aguix->DrawText( win, font, tstr, dx, dy );
-    }
+    DrawableCont dc( _aguix, win );
+    _aguix->DrawText( dc, font, tstr, dx, dy, text_color );
   }
   _freesafe( tstr );
 
@@ -285,18 +281,18 @@ void Button::redraw()
   /* now draw the button */
 
   if( showe == true ) {
-    _aguix->setFG( usegc, 2 );
-    _aguix->DrawTriangleFilled( win, usegc, px1, py1, px2, py2, px3, py3 );
-    _aguix->setFG( usegc, 0 );
-    _aguix->DrawTriangleFilled( win, usegc, px1, py1, _w-1, 0, px3, py3 );
+    _aguix->setFG( 2 );
+    _aguix->DrawTriangleFilled( win, px1, py1, px2, py2, px3, py3 );
+    _aguix->setFG( 0 );
+    _aguix->DrawTriangleFilled( win, px1, py1, _w-1, 0, px3, py3 );
   }
   
-  _aguix->drawBorder( win, usegc, ( state == 0 ) ? false : true, 0, 0, _w, _h, ear_width - 1 );
+  _aguix->drawBorder( win, ( state == 0 ) ? false : true, 0, 0, _w, _h, ear_width - 1 );
   if( showe == true ) {
-    _aguix->setFG( usegc, 1 );
-    _aguix->DrawLine( win, usegc, px1, py1, px2, py2 );
-    _aguix->DrawLine( win, usegc, px2, py2, px3, py3 );
-    _aguix->DrawLine( win, usegc, px1, py1, px3, py3 );
+    _aguix->setFG( 1 );
+    _aguix->DrawLine( win, px1, py1, px2, py2 );
+    _aguix->DrawLine( win, px2, py2, px3, py3 );
+    _aguix->DrawLine( win, px1, py1, px3, py3 );
   }
 
   _aguix->Flush();
@@ -372,7 +368,7 @@ bool Button::handleMessage(XEvent *E,Message *msg)
 		setState( instate );
 		agmsg->button.state = instate;
 	      }
-	      _aguix->putAGMsg(agmsg);
+              msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 	      returnvalue=true;
 	    }
 	  }
@@ -382,12 +378,12 @@ bool Button::handleMessage(XEvent *E,Message *msg)
 	    agmsg->type=AG_BUTTONRELEASED;
 	    agmsg->button.button=this;
 	    agmsg->button.state=instate;
-	    _aguix->putAGMsg(agmsg);
+            msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 	    agmsg = AGUIX_allocAGMessage();
 	    agmsg->type=AG_BUTTONCLICKED;
 	    agmsg->button.button=this;
 	    agmsg->button.state=instate;
-	    _aguix->putAGMsg(agmsg);
+            msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 	  }
 	  if(instate!=0) {
 	    setState(0);
@@ -430,7 +426,7 @@ bool Button::handleMessage(XEvent *E,Message *msg)
 	    agmsg->type=AG_BUTTONCLICKED;
 	    agmsg->button.button=this;
 	    agmsg->button.state=1;
-	    _aguix->putAGMsg(agmsg);
+            msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 	    if(instate!=0) {
 	      setState(0);
 	      instate=0;
