@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: button.h,v 1.11 2005/05/15 13:45:19 ralf Exp $ */
+/* $Id: button.h,v 1.12 2005/10/05 19:37:49 ralf Exp $ */
 
 #ifndef BUTTON_H
 #define BUTTON_H
@@ -78,7 +78,6 @@ private:
   char *text[2];
   int fg[2];
   int bg[2];
-  int lastbg;
   bool dual;
   int data;
   int state;
@@ -90,6 +89,7 @@ private:
 
   static const char *type;
   void init_class();
+  void prepareBG( bool force = false );
 };
 
 #endif
