@@ -23,14 +23,33 @@
 #ifndef CALLBACK_H
 #define CALLBACK_H
 
-class GUIElement;
+#include "aguixdefs.h"    
+#include "message.h"
+
+class Widget;
 
 class CallBack
 {
-public:
-  virtual ~CallBack() {}
-  virtual void run( GUIElement *, int value = 0 ) = 0;
-  virtual void run( GUIElement *, void *p ) = 0;
+ public:
+  CallBack() {}
+  virtual ~CallBack() = 0;
+
+  /*
+   * plain callback with no special infos
+   */
+  virtual void run_plain( Widget * );
+  
+  /*
+   * Callback with int value
+   * falls back to run( Widget *) if not overwritten
+   */
+  virtual void run_int( Widget *, int value );
+
+  /*
+   * Callback with message describing the event in detail
+   * falls back to run( Widget *) if not overwritten
+   */
+  virtual void run( Widget *, AGMessage &msg );
 };
 
 #endif
