@@ -23,6 +23,7 @@
 #include "choosebutton.h"
 #include "awindow.h"
 #include "guielement.h"
+#include "drawablecont.hh"
 
 const char *ChooseButton::type="ChooseButton";
 
@@ -174,15 +175,13 @@ void ChooseButton::cbredraw()
 
 void ChooseButton::lredraw()
 {
-  GC usegc;
   if ( isCreated() == false ) return;
   if ( lwin == 0 ) return;
-  if(font==NULL) usegc=0; else usegc=font->getGC();
   _aguix->SetWindowBG(lwin,_parent->getBG());
   _aguix->ClearWin(lwin);
-  _aguix->setFG(usegc,labelcolor);
-  if(font==NULL) _aguix->DrawText(lwin,label,0,0);
-  else _aguix->DrawText(lwin,font,label,0,0);
+
+  DrawableCont dc( _aguix, lwin );
+  _aguix->DrawText( dc, font, label, 0, 0, labelcolor );
 
   if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
     if ( strlen( label ) > 0 ) {
@@ -204,7 +203,7 @@ void ChooseButton::setState(bool tstate)
   cbredraw();
 }
 
-int ChooseButton::getState() const
+bool ChooseButton::getState() const
 {
   return state;
 }
@@ -241,7 +240,7 @@ bool ChooseButton::handleMessage(XEvent *E,Message *msg)
 	}
 	cross=true;
 	agmsg->choose.state=state;
-	_aguix->putAGMsg(agmsg);
+        msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 	returnvalue=true;
       } else {
         if(state==instate) {
@@ -249,12 +248,12 @@ bool ChooseButton::handleMessage(XEvent *E,Message *msg)
           agmsg->type=AG_CHOOSERELEASED;
           agmsg->choose.button=this;
           agmsg->choose.state=state;
-          _aguix->putAGMsg(agmsg);
+          msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
           agmsg = AGUIX_allocAGMessage();
           agmsg->type=AG_CHOOSECLICKED;
           agmsg->choose.button=this;
           agmsg->choose.state=state;
-          _aguix->putAGMsg(agmsg);
+          msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
           laststate=state;
         }
         cross=false;
@@ -285,7 +284,7 @@ bool ChooseButton::handleMessage(XEvent *E,Message *msg)
 	    agmsg->type=AG_CHOOSECLICKED;
 	    agmsg->choose.button=this;
 	    agmsg->choose.state=state;
-	    _aguix->putAGMsg(agmsg);
+            msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 	    laststate=state;
 	    cross=false;
 	  }
