@@ -1,6 +1,6 @@
 /* condvar.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2006 Ralf Hoffmann.
+ * Copyright (C) 2002-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -56,6 +56,49 @@ void CondVar::wait()
   return;
 }
 
+void CondVar::timedWaitRel( int microseconds )
+{
+  int oldcount;
+  struct timespec ts;
+  struct timeval tv;
+
+  //TODO another way of handling this case could be locking the mutex
+  if ( _owner != pthread_self() )
+    return;
+
+  _owner = 0;
+  oldcount = _owncount;
+  _owncount = 0;
+
+#ifdef THREAD_DEBUG
+  printf( "(%d,%p)::wait %d\n", pthread_self(), this, oldcount );
+#endif
+
+  // POSIX clock_gettime could also be used
+  
+  if ( gettimeofday( &tv, NULL ) == 0 ) {
+      ts.tv_sec = tv.tv_sec + microseconds / 1000000;
+      ts.tv_nsec = ( tv.tv_usec + ( microseconds % 1000000 ) ) * 1000;
+  } else {
+      printf( "AGUIX:Error in gettimeofday\n" );
+      ts.tv_sec = ts.tv_nsec = 0;
+  }
+
+  if ( ts.tv_nsec >= 1000000000 ) {
+      ts.tv_sec++;
+      ts.tv_nsec -= 1000000000;
+  }
+
+  pthread_cond_timedwait( &_condvar, &_mutex, &ts);
+#ifdef THREAD_DEBUG
+  printf( "(%d)::wait end\n", pthread_self() );
+#endif
+
+  _owner = pthread_self();
+  _owncount = oldcount;
+  return;
+}
+
 void CondVar::signal()
 {
   pthread_cond_signal( &_condvar );
