@@ -1,6 +1,6 @@
 /* cyclebutton.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,17 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: cyclebutton.h,v 1.10 2005/10/05 19:39:15 ralf Exp $ */
 
 #ifndef CYCLEBUTTON_H
 #define CYCLEBUTTON_H
 
 #include "aguixdefs.h"
 #include "guielement.h"
+#include <vector>
+#include <string>
 
 class AWindow;
 class AGUIXFont;
-class List;
 
 class CycleButton:public GUIElement {
 public:
@@ -40,7 +40,7 @@ public:
   CycleButton( const CycleButton &other );
   CycleButton &operator=( const CycleButton &other );
 
-  char *getOption(int);
+  const char *getOption(int);
   int addOption(const char *);
   int setOption( int, const char * );
   int getSelectedOption() const;
@@ -62,7 +62,7 @@ public:
   void setOption(int index);
   int getMaxSize() const;
 protected:
-  List *options;
+  std::vector<std::string> options;
   int act_opt;
   int fg;
   int bg;
