@@ -1,6 +1,6 @@
 /* dndtext.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: dndtext.cc,v 1.9 2005/08/16 20:48:50 ralf Exp $ */
 
 #include "dndtext.h"
 #include "aguix.h"
@@ -26,7 +25,7 @@
 #include "awindow.h"
 #include "drawablecont.hh"
 
-DNDText::DNDText( AGUIX *parent, char *ttext, int tfg, int tbg, AGUIXFont *tfont ) : DNDElement( parent )
+DNDText::DNDText( AGUIX *parent, const char *ttext, int tfg, int tbg, AGUIXFont *tfont ) : DNDElement( parent )
 {
   this->text=dupstring(ttext);
   this->fg=tfg;
