@@ -1,6 +1,6 @@
 /* dndtext.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: dndtext.h,v 1.8 2004/10/27 20:39:27 ralf Exp $ */
 
 #ifndef DNDTEXT_H
 #define DNDTEXT_H
@@ -31,7 +30,7 @@ class AGUIXFont;
 class DNDText:public DNDElement
 {
 public:
-  DNDText( AGUIX *, char*, int, int, AGUIXFont* );
+  DNDText( AGUIX *, const char*, int, int, AGUIXFont* );
   virtual ~DNDText();
   DNDText( const DNDText &other );
   DNDText &operator=( const DNDText &other );
