@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: fieldlistview.cc,v 1.68 2005/12/11 19:21:14 ralf Exp $ */
 
 #include "fieldlistview.h"
 #include <stdlib.h>
@@ -30,7 +29,12 @@ const char *FieldListView::type="FieldListView";
 
 unsigned int FieldListView::_select_button = Button1, FieldListView::_select_buttonmask = Button1Mask;
 unsigned int FieldListView::_activate_button = Button2, FieldListView::_activate_buttonmask = Button2Mask;
+unsigned int FieldListView::_activate_mod = 0;
 unsigned int FieldListView::_scroll_button = Button3, FieldListView::_scroll_buttonmask = Button3Mask;
+unsigned int FieldListView::_scroll_mod = 0;
+unsigned int FieldListView::_entry_pressed_msg_button = Button3,
+             FieldListView::_entry_pressed_msg_buttonmask = Button3Mask,
+             FieldListView::_entry_pressed_msg_mod = ShiftMask;
 FieldListView::mouse_select_t FieldListView::_select_mode = FieldListView::MOUSE_SELECT_NORMAL;
 
 FieldListView::FieldListView( AGUIX *caguix, int cx, int cy, int cwidth, int cheight, int cdata ):GUIElement( caguix )
@@ -987,7 +991,7 @@ bool FieldListView::handleMessage( XEvent *E, Message *msg )
   else if ( headerMode != HEADER_IDLE ) handleHeader( msg );
   else {
     if ( msg->type == ButtonPress ) {
-      // jetzt men wir was machen
+      // jetzt muessen wir was machen
       bool isc = false;
       if ( msg->window == hbarwin ) {
 	takeFocus();
@@ -1005,8 +1009,10 @@ bool FieldListView::handleMessage( XEvent *E, Message *msg )
 	  // field clicked
 	  handleHeader( msg );
 	} else {
-	  if ( msg->button == _scroll_button ) handleThird( msg );
-	  else if ( ( msg->button == Button4 ) || ( msg->button == Button5 ) ) {
+	  if ( msg->button == _scroll_button &&
+               checkForValidButtonMod( msg->button, msg->keystate, _scroll_mod ) == true ) {
+              handleThird( msg );
+          } else if ( ( msg->button == Button4 ) || ( msg->button == Button5 ) ) {
 	    gettimeofday( &t2, NULL );
 	    s = abs( (int)( t2.tv_sec - lastwheel.tv_sec ) );
 	    us = t2.tv_usec - lastwheel.tv_usec;
@@ -1022,9 +1028,13 @@ bool FieldListView::handleMessage( XEvent *E, Message *msg )
 	    if ( msg->button == Button4 ) scrollV1( -scrollspeed );
 	    else if ( msg->button == Button5 ) scrollV1( scrollspeed );
 	    lastwheel = t2;
-	  } else if ( msg->button == _activate_button ) {
+	  } else if ( msg->button == _activate_button &&
+                      checkForValidButtonMod( msg->button, msg->keystate, _activate_mod ) == true ) {
 	    handleMiddle( msg );
-	  } else {
+	  } else if ( msg->button == _entry_pressed_msg_button &&
+                      checkForValidButtonMod( msg->button, msg->keystate, _entry_pressed_msg_mod ) == true ) {
+	    handleEntryPressed( msg );
+	  } else if ( msg->button == _select_button ) {
 	    handleSelect( msg );
 	  }
 	}
@@ -1138,7 +1148,7 @@ void FieldListView::hbarredraw()
     if ( dw < 10 ) dw = 10;
 
     int a = maxtextwidth - getInnerWidth();
-    double b = tw - dw;  // das was brig bleibt
+    double b = tw - dw;  // das was uebrig bleibt
     b /= a;            // verteilt sich auch die nichtsichtbaren Zeichen
     tx = tx + hbar_height + (int)( xoffset * b );
     tw = dw;
@@ -1213,7 +1223,7 @@ void FieldListView::vbarredraw()
 			      arrow_up[2].x, arrow_up[2].y );
 
   // jetzt noch die eigentliche Leiste
-  th-=2*tw;  // Hhe wenn alles anzeigbar ist
+  th-=2*tw;  // Hoehe wenn alles anzeigbar ist
   tw-=2;
   tx++;
   int curelements=getElements();
@@ -1224,7 +1234,7 @@ void FieldListView::vbarredraw()
     if ( dh < 10 ) dh = 10;
 
     int a = curelements - maxdisplayv;
-    double b=th-dh;  // das was brig bleibt
+    double b=th-dh;  // das was uebrig bleibt
     b/=a;            // verteilt sich auch die nichtsichtbaren Zeichen
     ty=ty+vbar_width+(int)(yoffset*b);
     th=dh;
@@ -1449,8 +1459,7 @@ int FieldListView::selectRowsRange( int startRow, int endRow, bool state )
 void FieldListView::handleSelect( Message *msg )
 {
   int j;
-  Window root, child;
-  int root_x, root_y, win_x, win_y;
+  int win_x, win_y;
   unsigned int keys_buttons;
   int newelement;
   AGMessage *agmsg;
@@ -1527,16 +1536,7 @@ void FieldListView::handleSelect( Message *msg )
       keys_buttons = msg->keystate & ( ShiftMask | ControlMask );
       if ( _select_mode == MOUSE_SELECT_NORMAL ||
 	   keys_buttons == ControlMask ) {
-	//    _aguix->queryPointer( win, &mx, &my );
-	XQueryPointer( _aguix->getDisplay(),
-		       msg->window,
-		       &root,
-		       &child,
-		       &root_x,
-		       &root_y,
-		       &win_x,
-		       &win_y,
-		       &keys_buttons );
+          _aguix->queryPointer( win, &win_x, &win_y, &keys_buttons );
 	if ( ( keys_buttons & _select_buttonmask ) != 0 ) {
 	  j = getRowForMouseY( win_y );
 	  if ( ( j < 0 ) && ( yoffset > 0 ) ) {
@@ -1798,7 +1798,7 @@ void FieldListView::handleHBar( Message *msg )
     if ( dw < 10 ) dw = 10;
     
     int a = maxtextwidth - getInnerWidth();
-    b = tw - dw;  // das was brig bleibt
+    b = tw - dw;  // das was uebrig bleibt
     b /= a;            // verteilt sich auch die nichtsichtbaren Zeichen
     tx += hbar_height + (int)( xoffset * b );
     tw = dw;
@@ -1957,7 +1957,7 @@ void FieldListView::handleVBar(Message *msg)
   tw = vbar_width;
   tx = 0;
   ty = 0;
-  th -= 2 * tw;  // Hhe wenn alles anzeigbar ist
+  th -= 2 * tw;  // Hoehe wenn alles anzeigbar ist
   tw -= 2;
   tx++;
   ty++;
@@ -1968,7 +1968,7 @@ void FieldListView::handleVBar(Message *msg)
     if ( dh < 10 ) dh = 10;
     
     int a = curelements - maxdisplayv;
-    b = th - dh;     // das was brig bleibt
+    b = th - dh;     // das was uebrig bleibt
     b /= a;          // verteilt sich auch die nichtsichtbaren Zeichen
     ty += vbar_width + (int)( yoffset * b );
     th = dh;
@@ -2807,7 +2807,7 @@ int FieldListView::getInnerWidth() const
 int FieldListView::getInnerHeight() const
 {
   //TODO: Muss ich showHeader beachten?
-  //  Momentan lege ich Wert darauf, da dies gerade nicht drin ist
+  //  Momentan lege ich Wert darauf, dass dies gerade nicht drin ist
   //  vbar Hoehe haengt davon ab
   int th, bw;
 
@@ -3527,9 +3527,9 @@ int FieldListView::getUsedFieldWidth( int field )
     return fieldwidth[ field ];
 }
 
-int FieldListView::changeButtonFunction( buttonfunction_t bf, int button )
+int FieldListView::changeButtonFunction( buttonfunction_t bf, int button, int mod )
 {
-  unsigned int *buttonvar = NULL, *maskvar = NULL;
+  unsigned int *buttonvar = NULL, *maskvar = NULL, *modvar = NULL;
 
   if ( bf == SELECT_BUTTON ) {
     buttonvar = &_select_button;
@@ -3537,9 +3537,15 @@ int FieldListView::changeButtonFunction( buttonfunction_t bf, int button )
   } else if ( bf == ACTIVATE_BUTTON ) {
     buttonvar = &_activate_button;
     maskvar = &_activate_buttonmask;
+    modvar = &_activate_mod;
   } else if ( bf == SCROLL_BUTTON ) {
     buttonvar = &_scroll_button;
     maskvar = &_scroll_buttonmask;
+    modvar = &_scroll_mod;
+  } else if ( bf == ENTRY_PRESSED_MSG_BUTTON ) {
+    buttonvar = &_entry_pressed_msg_button;
+    maskvar = &_entry_pressed_msg_buttonmask;
+    modvar = &_entry_pressed_msg_mod;
   } else return 1;
 
   switch ( button ) {
@@ -3556,6 +3562,11 @@ int FieldListView::changeButtonFunction( buttonfunction_t bf, int button )
       *maskvar = Button3Mask;
       break;
   }
+  
+  if ( modvar != NULL ) {
+      *modvar = KEYSTATEMASK( mod );
+  }
+  
   return 0;
 }
 
@@ -3672,3 +3683,55 @@ FieldListView::ColorDef FieldListView::getColor( int row ) const
   col.setBG( CC_SELACT, elementarray[ row ]->getBG( CC_SELACT ) );
   return col;
 }
+
+bool FieldListView::checkForValidButtonMod( unsigned int button,
+                                            unsigned int keystate,
+                                            unsigned int matching_mod )
+{
+    if ( KEYSTATEMASK( keystate ) == matching_mod ) return true;
+    if ( matching_mod != 0 ) return false;
+    
+    if ( button == _activate_button &&
+         KEYSTATEMASK( keystate ) == _activate_mod ) return false;
+    
+    if ( button == _scroll_button &&
+         KEYSTATEMASK( keystate ) == _scroll_mod ) return false;
+
+    if ( button == _entry_pressed_msg_button &&
+         KEYSTATEMASK( keystate ) == _entry_pressed_msg_mod ) return false;
+    
+    return true;
+}
+
+void FieldListView::handleEntryPressed( Message *msg )
+{
+    int j;
+    int element;
+    AGMessage *agmsg;
+    
+    if ( isCreated() == false ) return;
+    
+    if ( msg->type == ButtonPress ) {
+        if ( msg->window != win ) return;
+        
+        j = getRowForMouseY( msg->mousey );
+        if ( j < 0 ) return;
+        if ( j >= maxdisplayv ) return;
+        
+        element = j + yoffset;
+        if ( isValidRow( element ) == false ) {
+            element = -1;
+        } else {
+            //setActiveRow( element );
+            //runSelectHandler( element );
+        }
+        
+        agmsg = AGUIX_allocAGMessage();
+        agmsg->fieldlv.lv = this;
+        agmsg->fieldlv.row = element;
+        agmsg->fieldlv.time = msg->time;
+        agmsg->fieldlv.mouse = true;
+        agmsg->type = AG_FIELDLV_ENTRY_PRESSED;
+        msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+    }
+}
