@@ -48,9 +48,7 @@ FieldListViewDND::FieldListViewDND( AGUIX *taguix,
 
 void FieldListViewDND::handleSelect(Message *msg)
 {
-  Window root, child;
-  int root_x, root_y, win_x, win_y;
-  unsigned int keys_buttons;
+  int win_x, win_y;
   AGMessage *agmsg;
   
   if ( isCreated() == false ) return;
@@ -65,16 +63,8 @@ void FieldListViewDND::handleSelect(Message *msg)
       if ( ( msg->button == _scroll_button ) &&
 	   ( selectMode == SELECT_HOLD ) ){
 	dndMode = DND_ACTIVE;
-
-	XQueryPointer( _aguix->getDisplay(),
-		       win,
-		       &root,
-		       &child,
-		       &root_x,
-		       &root_y,
-		       &win_x,
-		       &win_y,
-		       &keys_buttons );
+        
+        _aguix->queryPointer( win, &win_x, &win_y );
 	if ( isValidRow( clickLastSelectedRow ) == true ) {
 	  colorclass_t ti;
 	  
