@@ -1,6 +1,6 @@
 /* fieldlistviewdnd.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2004 Ralf Hoffmann.
+ * Copyright (C) 2002-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: fieldlistviewdnd.h,v 1.5 2004/10/27 20:38:56 ralf Exp $ */
 
 #ifndef FIELDLISTVIEWDND_H
 #define FIELDLISTVIEWDND_H
@@ -26,6 +25,8 @@
 #include "aguixdefs.h"
 #include "fieldlistview.h"
 #include "dndtext.h"
+#include <vector>
+#include <string>
 
 class FieldListViewDND:public FieldListView
 {
@@ -38,16 +39,14 @@ public:
   virtual const char *getType() const;
   virtual bool isType(const char *type) const;
   void removealldndtexts();
-  void removedndtextat(int);
-  void replacedndtext(int,char*);
-  void insertdndtext(int,char*);
-  void adddndtext(char*);
+  void replacedndtext( int, const char* );
+  void adddndtext( const char* );
   
   void setSizeDNDText(int);
 private:
   static const char *type;
   virtual void handleSelect(Message *msg);
-  ArrayList *dndtexts;
+  std::vector<std::string> dndtexts;
 
   typedef enum { DND_IDLE, DND_DEACTIVE, DND_ACTIVE } dndMode_t;
   dndMode_t dndMode;
