@@ -33,8 +33,6 @@ GUIElement::GUIElement(AGUIX *taguix) : Widget( taguix )
   _h = 1;
   win=0;
   visible = false;
-  _allow_timerevent_break = false;
-  _nr_of_last_event_break = 0;
   cb = NULL;
   sendMsg = true;
 }
@@ -208,21 +206,6 @@ bool GUIElement::isVisible() const
   }
 }
 
-bool GUIElement::getAllowTimerEventBreak() const
-{
-  return _allow_timerevent_break;
-}
-
-long GUIElement::getNrOfLastEventBreak() const
-{
-  return _nr_of_last_event_break;
-}
-
-void GUIElement::setNrOfLastEventBreak( long t )
-{
-  _nr_of_last_event_break = t;
-}
-
 void GUIElement::connect( CallBack *new_cb )
 {
   cb = new_cb;
