@@ -60,9 +60,6 @@ public:
   virtual void show();
   bool isVisible() const;
   bool handleMessage(XEvent *,Message *msg);
-  bool getAllowTimerEventBreak() const;
-  long getNrOfLastEventBreak() const;
-  void setNrOfLastEventBreak( long t );
 
   void connect( CallBack *new_cb );
   void setSendMessage( bool nv );
@@ -75,8 +72,6 @@ protected:
   void doCreateStuff();
   void doDestroyStuff();
   bool visible;
-  bool _allow_timerevent_break;
-  long _nr_of_last_event_break;
 
   int msgAndCB( std::auto_ptr<AGMessage> msg );
   int callback( int val );
