@@ -1,6 +1,6 @@
-/* karteicyclebutton.cc
+/* karteibutton.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004-2005 Ralf Hoffmann.
+ * Copyright (C) 2004-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: karteibutton.cc,v 1.7 2005/10/17 20:05:58 ralf Exp $ */
 
 #include "karteibutton.h"
 #include "awindow.h"
@@ -81,7 +80,6 @@ KarteiButton::KarteiButton( AGUIX *taguix,
 void KarteiButton::redraw()
 {
   GC usegc;
-  char *tstr;
   int ch;
   int basex, basey, midy, delx, i, dx, dx2, sx, sy, ex, ey;
   int act_x1 = -1, act_x2 = -1;
@@ -111,7 +109,7 @@ void KarteiButton::redraw()
   // second to draw lines and text
   for ( int run = 0; run < 2; run++ ) {
     basex = 0;
-    for ( i = 0; i < options->size(); i++ ) {
+    for ( i = 0; i < (int)options.size(); i++ ) {
       sx = basex;
       dx = 2 * delx;
       
@@ -153,7 +151,7 @@ void KarteiButton::redraw()
 			  sx + dx, 0 );
       }
       
-      tstr = dupstring((char*)options->getElementAt( i ) );
+      const char *tstr = options[i].c_str();
       
       dx2 = _aguix->getTextWidth( tstr, font );
       dx2 += 2 * delx;
@@ -202,8 +200,6 @@ void KarteiButton::redraw()
 	_aguix->DrawText( dc, font, tstr, sx + dx + delx, 1, 1 );
       }
 
-      _freesafe( tstr );
-
       if ( run != 0 ) {
 	if ( ( getAcceptFocus() == true ) &&
 	     ( getHasFocus() == true ) &&
@@ -261,10 +257,10 @@ bool KarteiButton::handleMessage(XEvent *E,Message *msg)
 	if ( ( state != 0 ) &&
 	     ( instate != 0 ) &&
 	     ( opt >= 0 ) ) {
-	  if ( options->size() > 0 ) {
+	  if ( options.size() > 0 ) {
 	    if ( msg->button == Button1 ) {
 	      act_opt = opt;
-	      if ( act_opt >= options->size() ) act_opt = 0;
+	      if ( act_opt >= (int)options.size() ) act_opt = 0;
 	    }
 	  }
 	  
@@ -309,14 +305,14 @@ bool KarteiButton::handleMessage(XEvent *E,Message *msg)
     }
   } else if ( msg->type == KeyPress ) {
     if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
-      if ( options->size() > 0 ) {
+      if ( options.size() > 0 ) {
 	if ( isVisible() == true ) {
 	  if ( _parent->isTopParent( msg->window ) == true ) {
 	    switch ( msg->key ) {
 	    case XK_space:
 	      if ( act_opt != focusPos ) {
 		act_opt = focusPos;
-		if ( act_opt >= options->size() ) act_opt = 0;
+		if ( act_opt >= (int)options.size() ) act_opt = 0;
 		
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_KARTEIBUTTONCLICKED;
@@ -341,7 +337,7 @@ bool KarteiButton::handleMessage(XEvent *E,Message *msg)
 	      }
 	      break;
 	    case XK_Right:
-	      if ( ( focusPos + 1 ) < options->size() ) {
+                if ( ( focusPos + 1 ) < (int)options.size() ) {
 		focusPos++;
 		redraw();
 	      }
@@ -375,14 +371,14 @@ bool KarteiButton::isType(const char *qtype) const
 
 int KarteiButton::getMaxSize() const
 {
-  char *tstr;
-  int delx, i, dx2, tw;
+  const char *tstr;
+  int delx, dx2, tw;
 
   delx = _h / 4;
   tw = 2 * delx;
   
-  for ( i = 0; i < options->size(); i++ ) {
-    tstr = (char*)options->getElementAt( i );
+  for ( unsigned int i = 0; i < options.size(); i++ ) {
+    tstr = options[i].c_str();
     dx2 = _aguix->getTextWidth( tstr, font );
     dx2 += 2 * delx;
     
@@ -401,20 +397,20 @@ void KarteiButton::setOptionChangeCallback( void (*optionChangeCallback_arg)( cl
 
 int KarteiButton::findClickedOption( int mx )
 {
-  char *tstr;
+  const char *tstr;
   int delx, i, dx2, tw, basex;
   int opt = -1;
 
   delx = _h / 4;
   basex = 0;
 
-  for ( i = 0; i < options->size(); i++ ) {
-    tstr = (char*)options->getElementAt( i );
+  for ( i = 0; i < (int)options.size(); i++ ) {
+    tstr = options[i].c_str();
     dx2 = _aguix->getTextWidth( tstr, font );
     dx2 += 2 * delx;
     
     tw = dx2 + 2 * delx;
-    if ( ( i == 0 ) || ( i == options->size() - 1 ) ) {
+    if ( ( i == 0 ) || ( i == (int)options.size() - 1 ) ) {
       tw += delx;
     }
 
@@ -433,9 +429,9 @@ void KarteiButton::setOption( int nv )
 {
   int old_opt = act_opt;
   
-  if ( ( nv >= 0 ) && ( options->size() > 0 ) ) {
+  if ( ( nv >= 0 ) && ( options.size() > 0 ) ) {
     act_opt = nv;
-    if ( act_opt >= options->size() ) act_opt = 0;
+    if ( act_opt >= (int)options.size() ) act_opt = 0;
 
     if ( old_opt != act_opt ) {
       if ( ( optionChangeCallback != NULL ) && ( act_opt >= 0 ) ) {
