@@ -1,6 +1,6 @@
 /* karteibutton.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004 Ralf Hoffmann.
+ * Copyright (C) 2004-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: karteibutton.h,v 1.2 2004/10/27 20:41:02 ralf Exp $ */
+/* $Id: karteibutton.h,v 1.4 2005/07/07 19:37:50 ralf Exp $ */
 
 #ifndef KARTEIBUTTON_H
 #define KARTEIBUTTON_H
@@ -27,7 +27,6 @@
 
 class KarteiButton:public CycleButton {
 public:
-  KarteiButton(AGUIX *aguix);
   KarteiButton(AGUIX *aguix,int x,int y,int width,
 	       int fg,int bg,int data);
   KarteiButton(AGUIX *aguix,int x,int y,int width,int height,
@@ -44,6 +43,8 @@ public:
   int getMaxSize() const;
   void setOptionChangeCallback( void (*optionChangeCallback_arg)( class Kartei *k1, unsigned int option ),
 				class Kartei *k2_arg );
+  using CycleButton::setOption;
+  void setOption( int nv );
 protected:
   static const char *type;
   void (*optionChangeCallback)( class Kartei *k1, unsigned int option );
