@@ -69,8 +69,8 @@ void waittime(unsigned long msec)
 {
 #ifdef HAVE_NANOSLEEP
   struct timespec wt;
-  wt.tv_nsec=msec*1000000;
-  wt.tv_sec=0;
+  wt.tv_nsec = ( msec % 1000 ) * 1000000;
+  wt.tv_sec = msec / 1000;
   nanosleep( &wt, NULL );
 #else
 
