@@ -54,6 +54,8 @@ AGMessage *AGUIX_allocAGMessage()
   agmsg = (AGMessage*)_allocsafe( sizeof( AGMessage ) );
   agmsg->type = AG_NONE;
   agmsg->key.keybuf = NULL;
+  agmsg->dnd.specialinfo.rowDataP = NULL;
+  agmsg->popupmenu.recursive_ids = NULL;
   return agmsg;
 }
 
@@ -69,6 +71,13 @@ void AGUIX_freeAGMessage( AGMessage *agmsg )
       if ( agmsg->dnd.specialinfo.rowDataP != NULL )
 	delete (agmsg->dnd.specialinfo.rowDataP);
     }
+    
+    if ( agmsg->type == AG_POPUPMENU_CLICKED ) {
+        if ( agmsg->popupmenu.recursive_ids != NULL ) {
+            delete agmsg->popupmenu.recursive_ids;
+        }
+    }
+    
     _freesafe( agmsg );
   }
 }
