@@ -1,6 +1,6 @@
 /* mutex.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2004 Ralf Hoffmann.
+ * Copyright (C) 2002-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,16 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: mutex.h,v 1.5 2004/10/27 20:42:08 ralf Exp $ */
 
 #ifndef MUTEX_H
 #define MUTEX_H
 
 #include "aguixdefs.h"
-
-#ifdef WANT_THREADS
 #include <pthread.h>
-#endif
 
 class MutEx
 {
@@ -36,17 +32,13 @@ public:
   virtual ~MutEx();
   MutEx( const MutEx &other );
   MutEx &operator=( const MutEx &other );
-  void lock();
-  void unlock();
-  bool trylock();
-protected:
-#ifdef WANT_THREADS
-  pthread_mutex_t mutex;
-  pthread_mutex_t dmutex;
-  pthread_cond_t condvar;
-  pthread_t owner;
-  int owncount;
-#endif  
+  virtual void lock();
+  virtual void unlock();
+  virtual bool trylock();
+ protected:
+  pthread_mutex_t _mutex;
+  pthread_t _owner;
+  int _owncount;
 };
 
 #endif
