@@ -1,6 +1,6 @@
 /* request.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: request.cc,v 1.37 2005/12/05 06:39:44 ralf Exp $ */
 
 #include "request.h"
 #include "aguix.h"
@@ -61,61 +60,68 @@ int Requester::request(const char *title,const char *text,const char *buttons, r
   return request( title, text, buttons, NULL, flags );
 }
 
-int Requester::request(const char *title,const char *text,const char *buttons, AWindow *twin, request_flags_t flags)
+int Requester::request(const char *title,const char *text,const char *buttons, const AWindow *twin, request_flags_t flags)
 {
   int i;
   Button **buts;
-  int w, h, nbuttons;
+  int nbuttons;
   char **buttonss;
 
   nbuttons=createLines(buttons,&buttonss);
-  w = h = 10;
-  AWindow *win=new AWindow(aguix,10,10,w,h,0, title );
+  
+  if ( twin == NULL && transientawin == NULL ) {
+    twin = aguix->getTransientWindow();
+  }
+  
+  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, title );
   win->create();
   if ( twin != NULL ) {
     win->setTransientForAWindow( twin );
   } else if ( transientawin != NULL ) {
     win->setTransientForAWindow( transientawin );
+  }
+
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 2 ), true );
+  ac1->setMinSpace( 0 );
+  ac1->setMaxSpace( 0 );
+  ac1->setBorderWidth( 5 );
+
+  AContainerBB *ac1_texts = dynamic_cast<AContainerBB*>( ac1->add( new AContainerBB( win, 1, 1 ), 0, 0 ) );
+  ac1_texts->setBorderWidth( 5 );
+  win->addMultiLineText( text, *ac1_texts, 0, 0, NULL, NULL );
+
+  AContainer *ac1_buttons = NULL;
+
+  if ( nbuttons == 1 ) {
+    ac1_buttons = ac1->add( new AContainer( win, 3, 1 ), 0, 1 );
+    ac1_buttons->setMinSpace( 0 );
+    ac1_buttons->setMaxSpace( 0 );
   } else {
-    if ( aguix->getTransientWindow() != NULL ) {
-      win->setTransientForAWindow( aguix->getTransientWindow() );
+    ac1_buttons = ac1->add( new AContainer( win, nbuttons, 1 ), 0, 1 );
+    ac1_buttons->setMinSpace( 5 );
+    ac1_buttons->setMaxSpace( -1 );
+  }
+  ac1_buttons->setBorderWidth( 0 );
+
+  buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
+
+  if ( nbuttons == 1 ) {
+    buts[0] = (Button*)ac1_buttons->add( new Button( aguix, 0, 0, buttonss[0], 1, 0, 0 ),
+                                         1, 0, AContainer::CFIX );
+  } else {
+    for ( i = 0; i < nbuttons; i++ ) {
+      buts[i] = (Button*)ac1_buttons->add( new Button( aguix, 0, 0, buttonss[i], 1, 0, i ),
+                                           i, 0, AContainer::CFIX );
     }
   }
-  int ty;
-  ty=5;
-
-  BevelBox *bb = (BevelBox*)win->add( new BevelBox( aguix, 5, ty, 10, 10, 1 ) );
-  ty += 5;
-
-  win->addTextFromString( text, 10, ty, 5, NULL, NULL, &ty );
-  ty += 5;
-  bb->resize( bb->getWidth(), ty - bb->getY() );
-  ty += 5;
-
-  win->maximizeX();
-  w = win->getWidth() + 10;
-
-  buts=(Button**)_allocsafe(nbuttons*sizeof(Button*));
-  for(i=0;i<nbuttons;i++) {
-    buts[i]=(Button*)win->add(new Button(aguix,0,ty,buttonss[i],1,0,i));
-  }
-  ty+=buts[0]->getHeight()+5;
-  AGUIX::scaleElementsW( w, 5, 10, -1, false, false, (GUIElement**)buts, NULL, nbuttons );
-
-  win->maximizeX();
-  w = win->getWidth() + 10;
 
   for ( i = 0; i < nbuttons; i++ ) {
     buts[i]->setAcceptFocus( true );
   }
   buts[0]->takeFocus();
   win->setDoTabCycling( true );
-  h=ty;
-  win->resize(w,h);
+  win->contMaximize( true, true );
   win->useStippleBackground();
-  bb->resize( w - 10, bb->getHeight() );
-  win->setMinSize(w,h);
-  win->setMaxSize( w, h );
   win->centerScreen();
   win->show();
   AGMessage *msg;
@@ -212,12 +218,6 @@ int Requester::request(const char *title,const char *text,const char *buttons, A
 	    }
 	  }
 	  break;
-        case AG_SIZECHANGED:
-	  for ( i = 0; i < nbuttons; i++ ) {
-	    buts[i]->move( buts[i]->getX(), msg->size.newh - win->getBorderWidth() - buts[i]->getHeight() );
-	  }
-	  AGUIX::scaleElementsW( msg->size.neww, 5, 10, -1, false, false, (GUIElement**)buts, NULL, nbuttons );
-	  break;
       }
       aguix->ReplyMessage(msg);
     }
@@ -239,54 +239,71 @@ int Requester::string_request( const char *title, const char *text, const char *
   return string_request( title, text, default_str, buttons, return_str, NULL, flags );
 }
 
-int Requester::string_request( const char *title, const char *text, const char *default_str, const char *buttons,char **return_str, AWindow *twin, request_flags_t flags)
+int Requester::string_request( const char *title, const char *text, const char *default_str, const char *buttons,char **return_str, const AWindow *twin, request_flags_t flags)
 {
   Button **buts;
-  int w, h, nbuttons;
+  int nbuttons;
   char **buttonss;
   StringGadget *sg;
-  int i, ty;
+  int i;
   
   nbuttons=createLines(buttons,&buttonss);
-  w = h = 10;
-  AWindow *win=new AWindow(aguix,10,10,w,h,0,title);
+
+  if ( twin == NULL && transientawin == NULL ) {
+    twin = aguix->getTransientWindow();
+  }
+  
+  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, title );
   win->create();
   if ( twin != NULL ) {
     win->setTransientForAWindow( twin );
   } else if ( transientawin != NULL ) {
     win->setTransientForAWindow( transientawin );
+  }
+
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 4 ), true );
+  ac1->setMinSpace( 0 );
+  ac1->setMaxSpace( 0 );
+  ac1->setBorderWidth( 5 );
+
+  AContainerBB *ac1_texts = dynamic_cast<AContainerBB*>( ac1->add( new AContainerBB( win, 1, 1 ), 0, 0 ) );
+  ac1_texts->setBorderWidth( 5 );
+  win->addMultiLineText( text, *ac1_texts, 0, 0, NULL, NULL );
+
+  sg = (StringGadget*)ac1->add( new StringGadget( aguix, 0, 0, 100, default_str, 0 ),
+                                0, 1, AContainer::CINCW );
+  sg->setAcceptFocus( true );
+
+  ac1->setMinHeight( 5, 0, 2 );
+
+  AContainer *ac1_buttons = NULL;
+
+  if ( nbuttons == 1 ) {
+    ac1_buttons = ac1->add( new AContainer( win, 3, 1 ), 0, 3 );
+    ac1_buttons->setMinSpace( 0 );
+    ac1_buttons->setMaxSpace( 0 );
   } else {
-    if ( aguix->getTransientWindow() != NULL ) {
-      win->setTransientForAWindow( aguix->getTransientWindow() );
+    ac1_buttons = ac1->add( new AContainer( win, nbuttons, 1 ), 0, 3 );
+    ac1_buttons->setMinSpace( 5 );
+    ac1_buttons->setMaxSpace( -1 );
+  }
+  ac1_buttons->setBorderWidth( 0 );
+
+  buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
+
+  if ( nbuttons == 1 ) {
+    buts[0] = (Button*)ac1_buttons->add( new Button( aguix, 0, 0, buttonss[0], 1, 0, 0 ),
+                                         1, 0, AContainer::CFIX );
+  } else {
+    for ( i = 0; i < nbuttons; i++ ) {
+      buts[i] = (Button*)ac1_buttons->add( new Button( aguix, 0, 0, buttonss[i], 1, 0, i ),
+                                           i, 0, AContainer::CFIX );
     }
   }
-  ty=5;
-
-  BevelBox *bb = (BevelBox*)win->add( new BevelBox( aguix, 5, ty, 10, 10, 1 ) );
-  ty += 5;
-
-  win->addTextFromString( text, 10, ty, 5, NULL, NULL, &ty );
-  ty += 5;
-  bb->resize( bb->getWidth(), ty - bb->getY() );
-  ty += 5;
-
-  sg=(StringGadget*)win->add(new StringGadget(aguix,5,ty,100,default_str,0));
-  sg->setAcceptFocus( true );
-  ty+=sg->getHeight()+5;
-  buts=(Button**)_allocsafe(nbuttons*sizeof(Button*));
-  for ( i = 0; i < nbuttons; i++ ) {
-    buts[i] = (Button*)win->add( new Button( aguix, 0, ty, buttonss[i], 1, 0, i ) );
-  }
-  ty += buts[0]->getHeight() + 5;
-  AGUIX::scaleElementsW( w, 5, 10, -1, false, false, (GUIElement**)buts, NULL, nbuttons );
-
-  win->maximizeX();
-  w = win->getWidth() + 5;
 
   for ( i = 0; i < nbuttons; i++ ) {
     buts[i]->setAcceptFocus( true );
   }
-  h=ty;
  
   sg->setXOffset( 0 );
   if ( default_str != NULL ) {
@@ -301,10 +318,8 @@ int Requester::string_request( const char *title, const char *text, const char *
 
   sg->takeFocus();
   win->useStippleBackground();
-  bb->resize( w - 10, bb->getHeight() );
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMinSize(w,h);
+  win->contMaximize( true );
   win->centerScreen();
   win->show();
   AGMessage *msg;
@@ -416,14 +431,6 @@ int Requester::string_request( const char *title, const char *text, const char *
 	    }
 	  }
 	  break;
-        case AG_SIZECHANGED:
-	  for ( i = 0; i < nbuttons; i++ ) {
-	    buts[i]->move( buts[i]->getX(), msg->size.newh - win->getBorderWidth() - buts[i]->getHeight() );
-	  }
-	  AGUIX::scaleElementsW( msg->size.neww, 5, -1, -1, true, true, (GUIElement**)(&sg), NULL, 1 );
-	  AGUIX::scaleElementsW( msg->size.neww, 5, 10, -1, false, false, (GUIElement**)buts, NULL, nbuttons );
-	  bb->resize( msg->size.neww - 10, bb->getHeight() );
-	  break;
       }
       aguix->ReplyMessage(msg);
     }
@@ -453,7 +460,7 @@ int Requester::request_choose( const char *title,
 			       const char *choose_text,
 			       bool &choose_var,
 			       const char *buttons,
-			       AWindow *twin,
+			       const AWindow *twin,
 			       request_flags_t flags )
 {
   int i;
@@ -464,16 +471,17 @@ int Requester::request_choose( const char *title,
   char **liness;
 
   nbuttons = createLines( buttons, &buttonss );
+
+  if ( twin == NULL && transientawin == NULL ) {
+    twin = aguix->getTransientWindow();
+  }
+  
   AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, title );
   win->create();
   if ( twin != NULL ) {
     win->setTransientForAWindow( twin );
   } else if ( transientawin != NULL ) {
     win->setTransientForAWindow( transientawin );
-  } else {
-    if ( aguix->getTransientWindow() != NULL ) {
-      win->setTransientForAWindow( aguix->getTransientWindow() );
-    }
   }
 
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
@@ -623,7 +631,7 @@ int Requester::request_choose( const char *title,
     }
   }
 
-  choose_var = ( cb1->getState() == 0 ) ? false : true;
+  choose_var = cb1->getState();
 
   delete win;
   for ( i = 0; i < nbuttons; i++ ) _freesafe( buttonss[i] );
@@ -643,7 +651,7 @@ int Requester::request( const char *title, TextStorage &ts, const char *buttons,
   return request( title, ts, buttons, NULL, flags );
 }
 
-int Requester::request( const char *title, TextStorage &ts, const char *buttons, AWindow *twin, request_flags_t flags )
+int Requester::request( const char *title, TextStorage &ts, const char *buttons, const AWindow *twin, request_flags_t flags )
 {
   int i;
   Button **buts;
@@ -651,16 +659,17 @@ int Requester::request( const char *title, TextStorage &ts, const char *buttons,
   char **buttonss;
 
   nbuttons = createLines( buttons, &buttonss );
+
+  if ( twin == NULL && transientawin == NULL ) {
+    twin = aguix->getTransientWindow();
+  }
+  
   AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, title );
   win->create();
   if ( twin != NULL ) {
     win->setTransientForAWindow( twin );
   } else if ( transientawin != NULL ) {
     win->setTransientForAWindow( transientawin );
-  } else {
-    if ( aguix->getTransientWindow() != NULL ) {
-      win->setTransientForAWindow( aguix->getTransientWindow() );
-    }
   }
 
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 2 ), true );
