@@ -31,7 +31,7 @@ class Requester
 public:
   Requester(class AGUIX *parent);
   Requester( class AGUIX *parent, class AWindow *twin );
-  ~Requester();
+  virtual ~Requester();
   Requester( const Requester &other );
   Requester &operator=( const Requester &other );
 
@@ -43,17 +43,17 @@ public:
 
   int request(const char *title,const char *text,const char *buttons);
   int request(const char *title,const char *text,const char *buttons, request_flags_t flags);
-  int request(const char *title,const char *text,const char *buttons, AWindow *twin, request_flags_t flags);
+  int request(const char *title,const char *text,const char *buttons, const AWindow *twin, request_flags_t flags);
   int string_request( const char *title, const char *lines, const char *default_str, const char *buttons,char **return_str);
   int string_request( const char *title, const char *lines, const char *default_str, const char *buttons,char **return_str, request_flags_t flags );
-  int string_request( const char *title, const char *lines, const char *default_str, const char *buttons,char **return_str, AWindow *twin, request_flags_t flags );
+  int string_request( const char *title, const char *lines, const char *default_str, const char *buttons,char **return_str, const AWindow *twin, request_flags_t flags );
   int request_choose( const char *title, const char *text, const char *choose_text, bool &choose_var, const char *buttons );
   int request_choose( const char *title, const char *text, const char *choose_text, bool &choose_var, const char *buttons, request_flags_t flags );
-  int request_choose( const char *title, const char *text, const char *choose_text, bool &choose_var, const char *buttons, AWindow *twin, request_flags_t flags );
+  int request_choose( const char *title, const char *text, const char *choose_text, bool &choose_var, const char *buttons, const AWindow *twin, request_flags_t flags );
 
   int request( const char *title, TextStorage &ts, const char *buttons );
   int request( const char *title, TextStorage &ts, const char *buttons, request_flags_t flags );
-  int request( const char *title, TextStorage &ts, const char *buttons, AWindow *twin, request_flags_t flags );
+  int request( const char *title, TextStorage &ts, const char *buttons, const AWindow *twin, request_flags_t flags );
 private:
   class AGUIX *aguix;
   AWindow *transientawin;
