@@ -59,7 +59,7 @@ Slider::Slider( AGUIX *caguix, int cx, int cy, int cwidth, int cheight, bool cve
   scrollDelta = 0;
   
   _init_timer_wait = 0;
-  _allow_timerevent_break = true;
+  setAllowTimerEventBreak( true );
 
   m_bg = -1;
 }
@@ -118,7 +118,7 @@ bool Slider::handleMessage( XEvent *E, Message *msg )
   if ( barMode != BAR_IDLE ) handleBar( msg );
   else {
     if ( msg->type == ButtonPress ) {
-      // jetzt men wir was machen
+      // jetzt muessen wir was machen
       bool isc = false;
       if ( msg->window == win ) {
 	takeFocus();
@@ -306,7 +306,7 @@ void Slider::redraw()
     if ( d < 10 ) d = 10;
 
     int a = maxlen - maxdisplay;
-    double b = ( ( vertical == true ) ? th : tw ) - d;  // das was brig bleibt
+    double b = ( ( vertical == true ) ? th : tw ) - d;  // das was uebrig bleibt
     b /= a;            // verteilt sich auch die nichtsichtbaren Zeichen
     if ( vertical == true ) {
       ty += (int)( offset * b );
@@ -405,7 +405,7 @@ void Slider::handleBar( Message *msg )
     if ( d < 10 ) d = 10;
 
     int a = maxlen - maxdisplay;
-    b = ( ( vertical == true ) ? th : tw ) - d;  // das was brig bleibt
+    b = ( ( vertical == true ) ? th : tw ) - d;  // das was uebrig bleibt
     b /= a;            // verteilt sich auch die nichtsichtbaren Zeichen
     if ( vertical == true ) {
       ty += (int)( offset * b );
