@@ -23,6 +23,7 @@
 #include "solidbutton.h"
 #include "lowlevelfunc.h"
 #include "awindow.h"
+#include "drawablecont.hh"
 
 const char *SolidButton::type="SolidButton";
 
@@ -31,6 +32,24 @@ SolidButton::~SolidButton()
   if(text!=NULL) _freesafe(text);
 }
 
+SolidButton::SolidButton(AGUIX *taguix,int tx,int ty,
+                         const char *ttext,int tfg,int tbg,bool tstate):GUIElement(taguix)
+{
+  int bw;
+
+  bw = 2;
+
+  _x = tx;
+  _y = ty;
+  _w = taguix->getTextWidth( ttext ) + taguix->getTextWidth( "  " );
+  _h = taguix->getCharHeight() + 2 * bw;
+  this->state = tstate;
+  this->text = dupstring( ttext );
+  this->fg = tfg;
+  this->bg = tbg;
+  font = NULL;
+}
+
 SolidButton::SolidButton(AGUIX *taguix,int tx,int ty,int width,
                          const char *ttext,int tfg,int tbg,bool tstate):GUIElement(taguix)
 {
@@ -114,7 +133,6 @@ void SolidButton::setState(bool tstate)
 
 void SolidButton::redraw()
 {
-  GC usegc;
   int len, strwidth;
   int bw;
 
@@ -124,11 +142,8 @@ void SolidButton::redraw()
   prepareBG();
   _aguix->ClearWin(win);
 
-  if(font==NULL) usegc=0; else usegc=font->getGC();
-
-  _aguix->drawBorder( win, usegc, state, 0, 0, _w, _h, 0 );
+  _aguix->drawBorder( win, state, 0, 0, _w, _h, 0 );
   
-  _aguix->setFG(usegc,fg);
   int ch;
   if(font==NULL) {
     ch=_aguix->getCharHeight();
@@ -147,8 +162,8 @@ void SolidButton::redraw()
     tstr[len] = '\0';
     int dx = _w / 2 - strwidth / 2;
 
-    if ( font == NULL ) _aguix->DrawText( win, tstr, dx, dy );
-    else _aguix->DrawText( win, font, tstr, dx, dy );
+    DrawableCont dc( _aguix, win );
+    _aguix->DrawText( dc, font, tstr, dx, dy, fg );
   }
   _freesafe(tstr);
   _aguix->Flush();
