@@ -34,14 +34,17 @@ int Thread::start()
 {
   int erg;
 
+  // lock var so actual run() only starts after _id is stored
+  _lock.lock();
   erg = pthread_create( &_id, NULL, thread_entry, this );
+  _lock.unlock();
   return erg;
 }
 
 void *Thread::thread_entry( void *me )
 {
-  ((Thread*)me)->run();
-  return NULL;
+    ((Thread*)me)->thread_run();
+    return NULL;
 }
 
 int Thread::join()
@@ -61,3 +64,11 @@ bool Thread::amIThisThread() const
     return true;
   return false;
 }
+
+void Thread::thread_run()
+{
+    _lock.lock();
+    _lock.unlock();
+    // after having got the lock _id is correct so amIThisThread works
+    run();
+}
