@@ -105,9 +105,8 @@ void DNDAction::normalmodedndaction( ActionMessage *am )
 	  // FE is already a copy of the real FE so we don't need to make another copy
 	  // but setFE does make a copy currently which doesn't hurt
           amsg.setFE( fe );
-          amsg.flags = ft->getDNDActionsGF();
 	  amsg.filetype = ft;
-	  amsg.getActionList = DNDAction::getActionList;
+          amsg.m_action_descr = RefCount<ActionDescr>( new DNDAction::DNDActionDescr() );
           am->getWorker()->interpret( ft->getDNDActions(), &amsg );
         }
       }
@@ -135,9 +134,8 @@ void DNDAction::normalmodedndaction( ActionMessage *am )
           ft = wconfig->getvoidtype();
           if(ft!=NULL) {
             amsg.setFE( NULL );
-            amsg.flags=ft->getDNDActionsGF();
 	    amsg.filetype = ft;
-	    amsg.getActionList = DNDAction::getActionList;
+            amsg.m_action_descr = RefCount<ActionDescr>( new DNDAction::DNDActionDescr() );
             am->getWorker()->interpret(ft->getDNDActions(),&amsg);
           }
         } else {
@@ -154,9 +152,8 @@ void DNDAction::normalmodedndaction( ActionMessage *am )
 		// NM_specialsourceExt already contains a duplicated FE so we can use
 		// it here without another copy
 		amsg.setFE( fe );
-		amsg.flags=ft->getDNDActionsGF();
 		amsg.filetype = ft;
-		amsg.getActionList = DNDAction::getActionList;
+                amsg.m_action_descr = RefCount<ActionDescr>( new DNDAction::DNDActionDescr() );
 		am->getWorker()->interpret(ft->getDNDActions(),&amsg);
 	      }
             }
@@ -169,15 +166,10 @@ void DNDAction::normalmodedndaction( ActionMessage *am )
   }
 }
 
-List *DNDAction::getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags )
+List *DNDAction::DNDActionDescr::get_action_list( WCFiletype *ft ) const
 {
-  if ( filetype == NULL ) return NULL;
-  
-  if ( return_flags != NULL ) {
-    *return_flags = filetype->getDNDActionsGF();
-  }
-
-  return filetype->getDNDActions();
+    if ( ft == NULL ) return NULL;
+    return ft->getDNDActions();
 }
 
 /***************
@@ -265,9 +257,8 @@ void DoubleClickAction::normalmodeddaction( ActionMessage *am )
 	  // I need to make a copy of fe as DNDMsg->getFE returns a pointer to the actual FE
 	  // setFE takes care of this at the moment
           amsg.setFE( fe );
-          amsg.flags=ft->getDoubleClickActionsGF();
 	  amsg.filetype = ft;
-	  amsg.getActionList = DoubleClickAction::getActionList;
+          amsg.m_action_descr = RefCount<ActionDescr>( new DoubleClickAction::DoubleClickActionDescr() );
           am->getWorker()->interpret(ft->getDoubleClickActions(),&amsg);
         }
       }
@@ -288,9 +279,8 @@ void DoubleClickAction::normalmodeddaction( ActionMessage *am )
 	  // FE is already a copy of the real FE so we don't need to make another copy
 	  // but setFE does make a copy currently which doesn't hurt
           amsg.setFE( fe );
-          amsg.flags = ft->getDoubleClickActionsGF();
 	  amsg.filetype = ft;
-	  amsg.getActionList = DoubleClickAction::getActionList;
+          amsg.m_action_descr = RefCount<ActionDescr>( new DoubleClickAction::DoubleClickActionDescr() );
           am->getWorker()->interpret( ft->getDoubleClickActions(), &amsg );
         }
       }
@@ -319,9 +309,8 @@ void DoubleClickAction::normalmodeddaction( ActionMessage *am )
           ft = wconfig->getvoidtype();
           if(ft!=NULL) {
             amsg.setFE( NULL );
-            amsg.flags=ft->getDoubleClickActionsGF();
 	    amsg.filetype = ft;
-	    amsg.getActionList = DoubleClickAction::getActionList;
+            amsg.m_action_descr = RefCount<ActionDescr>( new DoubleClickAction::DoubleClickActionDescr() );
             am->getWorker()->interpret(ft->getDoubleClickActions(),&amsg);
           }
         } else {
@@ -338,9 +327,8 @@ void DoubleClickAction::normalmodeddaction( ActionMessage *am )
 		// NM_specialsourceExt already contains a duplicated FE so we can use
 		// it here without another copy
 		amsg.setFE( fe );
-		amsg.flags=ft->getDoubleClickActionsGF();
 		amsg.filetype = ft;
-		amsg.getActionList = DoubleClickAction::getActionList;
+                amsg.m_action_descr = RefCount<ActionDescr>( new DoubleClickAction::DoubleClickActionDescr() );
 		am->getWorker()->interpret(ft->getDoubleClickActions(),&amsg);
 	      }
             }
@@ -353,15 +341,10 @@ void DoubleClickAction::normalmodeddaction( ActionMessage *am )
   }
 }
 
-List *DoubleClickAction::getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags )
+List *DoubleClickAction::DoubleClickActionDescr::get_action_list( WCFiletype *ft ) const
 {
-  if ( filetype == NULL ) return NULL;
-  
-  if ( return_flags != NULL ) {
-    *return_flags = filetype->getDoubleClickActionsGF();
-  }
-
-  return filetype->getDoubleClickActions();
+    if ( ft == NULL ) return NULL;
+    return ft->getDoubleClickActions();
 }
 
 /***************
@@ -449,9 +432,8 @@ void ShowAction::normalmodeshow( ActionMessage *am )
 	  // I need to make a copy of fe as DNDMsg->getFE returns a pointer to the actual FE
 	  // setFE takes care of this at the moment
           amsg.setFE( fe );
-          amsg.flags=ft->getShowActionsGF();
 	  amsg.filetype = ft;
-	  amsg.getActionList = ShowAction::getActionList;
+          amsg.m_action_descr = RefCount<ActionDescr>( new ShowAction::ShowActionDescr() );
           am->getWorker()->interpret(ft->getShowActions(),&amsg);
         }
       }
@@ -472,9 +454,8 @@ void ShowAction::normalmodeshow( ActionMessage *am )
 	  // FE is already a copy of the real FE so we don't need to make another copy
 	  // but setFE does make a copy currently which doesn't hurt
           amsg.setFE( fe );
-          amsg.flags = ft->getShowActionsGF();
 	  amsg.filetype = ft;
-	  amsg.getActionList = ShowAction::getActionList;
+          amsg.m_action_descr = RefCount<ActionDescr>( new ShowAction::ShowActionDescr() );
           am->getWorker()->interpret( ft->getShowActions(), &amsg );
         }
       }
@@ -503,9 +484,8 @@ void ShowAction::normalmodeshow( ActionMessage *am )
           ft = wconfig->getvoidtype();
           if(ft!=NULL) {
             amsg.setFE( NULL );
-            amsg.flags=ft->getShowActionsGF();
 	    amsg.filetype = ft;
-	    amsg.getActionList = ShowAction::getActionList;
+            amsg.m_action_descr = RefCount<ActionDescr>( new ShowAction::ShowActionDescr() );
             am->getWorker()->interpret(ft->getShowActions(),&amsg);
           }
         } else {
@@ -522,9 +502,8 @@ void ShowAction::normalmodeshow( ActionMessage *am )
 		// NM_specialsourceExt already contains a duplicated FE so we can use
 		// it here without another copy
 		amsg.setFE( fe );
-		amsg.flags=ft->getShowActionsGF();
 		amsg.filetype = ft;
-		amsg.getActionList = ShowAction::getActionList;
+                amsg.m_action_descr = RefCount<ActionDescr>( new ShowAction::ShowActionDescr() );
 		am->getWorker()->interpret(ft->getShowActions(),&amsg);
 	      }
             }
@@ -537,15 +516,10 @@ void ShowAction::normalmodeshow( ActionMessage *am )
   }
 }
 
-List *ShowAction::getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags )
+List *ShowAction::ShowActionDescr::get_action_list( WCFiletype *ft ) const
 {
-  if ( filetype == NULL ) return NULL;
-  
-  if ( return_flags != NULL ) {
-    *return_flags = filetype->getShowActionsGF();
-  }
-
-  return filetype->getShowActions();
+    if ( ft == NULL ) return NULL;
+    return ft->getShowActions();
 }
 
 /***************
@@ -633,9 +607,8 @@ void RawShowAction::normalmoderawshow( ActionMessage *am )
 	  // I need to make a copy of fe as DNDMsg->getFE returns a pointer to the actual FE
 	  // setFE takes care of this at the moment
           amsg.setFE( fe );
-          amsg.flags=ft->getRawShowActionsGF();
 	  amsg.filetype = ft;
-	  amsg.getActionList = RawShowAction::getActionList;
+          amsg.m_action_descr = RefCount<ActionDescr>( new RawShowAction::RawShowActionDescr() );
           am->getWorker()->interpret(ft->getRawShowActions(),&amsg);
         }
       }
@@ -656,9 +629,8 @@ void RawShowAction::normalmoderawshow( ActionMessage *am )
 	  // FE is already a copy of the real FE so we don't need to make another copy
 	  // but setFE does make a copy currently which doesn't hurt
           amsg.setFE( fe );
-          amsg.flags = ft->getRawShowActionsGF();
 	  amsg.filetype = ft;
-	  amsg.getActionList = RawShowAction::getActionList;
+          amsg.m_action_descr = RefCount<ActionDescr>( new RawShowAction::RawShowActionDescr() );
           am->getWorker()->interpret( ft->getRawShowActions(), &amsg );
         }
       }
@@ -687,9 +659,8 @@ void RawShowAction::normalmoderawshow( ActionMessage *am )
           ft = wconfig->getvoidtype();
           if(ft!=NULL) {
             amsg.setFE( NULL );
-            amsg.flags=ft->getRawShowActionsGF();
 	    amsg.filetype = ft;
-	    amsg.getActionList = RawShowAction::getActionList;
+            amsg.m_action_descr = RefCount<ActionDescr>( new RawShowAction::RawShowActionDescr() );
             am->getWorker()->interpret(ft->getRawShowActions(),&amsg);
           }
         } else {
@@ -706,9 +677,8 @@ void RawShowAction::normalmoderawshow( ActionMessage *am )
 		// NM_specialsourceExt already contains a duplicated FE so we can use
 		// it here without another copy
 		amsg.setFE( fe );
-		amsg.flags=ft->getRawShowActionsGF();
 		amsg.filetype = ft;
-		amsg.getActionList = RawShowAction::getActionList;
+                amsg.m_action_descr = RefCount<ActionDescr>( new RawShowAction::RawShowActionDescr() );
 		am->getWorker()->interpret(ft->getRawShowActions(),&amsg);
 	      }
             }
@@ -721,15 +691,10 @@ void RawShowAction::normalmoderawshow( ActionMessage *am )
   }
 }
 
-List *RawShowAction::getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags )
+List *RawShowAction::RawShowActionDescr::get_action_list( WCFiletype *ft ) const
 {
-  if ( filetype == NULL ) return NULL;
-  
-  if ( return_flags != NULL ) {
-    *return_flags = filetype->getRawShowActionsGF();
-  }
-
-  return filetype->getRawShowActions();
+    if ( ft == NULL ) return NULL;
+    return ft->getRawShowActions();
 }
 
 /***************
@@ -820,10 +785,8 @@ void UserAction::normalmodeuseraction( ActionMessage *am )
 	  // I need to make a copy of fe as DNDMsg->getFE returns a pointer to the actual FE
 	  // setFE takes care of this at the moment
           amsg.setFE( fe );
-          amsg.flags=ft->getUserActionsGF(nr);
 	  amsg.filetype = ft;
-	  amsg.getActionList = UserAction::getActionList;
-	  amsg.getActionListID = nr;
+          amsg.m_action_descr = RefCount<ActionDescr>( new UserAction::UserActionDescr( nr ) );
           am->getWorker()->interpret(ft->getUserActions(nr),&amsg);
         }
       }
@@ -844,10 +807,8 @@ void UserAction::normalmodeuseraction( ActionMessage *am )
 	  // FE is already a copy of the real FE so we don't need to make another copy
 	  // but setFE does make a copy currently which doesn't hurt
           amsg.setFE( fe );
-          amsg.flags = ft->getUserActionsGF( nr );
 	  amsg.filetype = ft;
-	  amsg.getActionList = UserAction::getActionList;
-	  amsg.getActionListID = nr;
+          amsg.m_action_descr = RefCount<ActionDescr>( new UserAction::UserActionDescr( nr ) );
           am->getWorker()->interpret( ft->getUserActions( nr ), &amsg );
         }
       }
@@ -876,10 +837,8 @@ void UserAction::normalmodeuseraction( ActionMessage *am )
           ft = wconfig->getvoidtype();
           if(ft!=NULL) {
             amsg.setFE( NULL );
-            amsg.flags=ft->getUserActionsGF(nr);
 	    amsg.filetype = ft;
-	    amsg.getActionList = UserAction::getActionList;
-	    amsg.getActionListID = nr;
+            amsg.m_action_descr = RefCount<ActionDescr>( new UserAction::UserActionDescr( nr ) );
             am->getWorker()->interpret(ft->getUserActions(nr),&amsg);
           }
         } else {
@@ -896,10 +855,8 @@ void UserAction::normalmodeuseraction( ActionMessage *am )
 		// NM_specialsourceExt already contains a duplicated FE so we can use
 		// it here without another copy
 		amsg.setFE( fe );
-		amsg.flags=ft->getUserActionsGF(nr);
 		amsg.filetype = ft;
-		amsg.getActionList = UserAction::getActionList;
-		amsg.getActionListID = nr;
+                amsg.m_action_descr = RefCount<ActionDescr>( new UserAction::UserActionDescr( nr ) );
 		am->getWorker()->interpret(ft->getUserActions(nr),&amsg);
 	      }
             }
@@ -1015,15 +972,14 @@ void UserAction::setNr( int n )
   if ( nr > 9 ) nr = 9;
 }
 
-List *UserAction::getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags )
+UserAction::UserActionDescr::UserActionDescr( int id ) : m_id( id )
 {
-  if ( filetype == NULL ) return NULL;
-  
-  if ( return_flags != NULL ) {
-    *return_flags = filetype->getUserActionsGF( id );
-  }
+}
 
-  return filetype->getUserActions( id );
+List *UserAction::UserActionDescr::get_action_list( WCFiletype *ft ) const
+{
+    if ( ft == NULL ) return NULL;
+    return ft->getUserActions( m_id );
 }
 
 /***************
