@@ -1,6 +1,6 @@
 /* basic_actions.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: basic_actions.h,v 1.12 2005/10/19 18:08:00 ralf Exp $ */
 
 #ifndef BASIC_ACTIONS_H
 #define BASIC_ACTIONS_H
@@ -43,7 +42,11 @@ public:
   int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 
-  static List *getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags );
+  class DNDActionDescr : public ActionDescr
+  {
+  public:
+      List *get_action_list( WCFiletype *ft ) const;
+  };
 protected:
   static const char *name;
   void normalmodedndaction( ActionMessage *am );
@@ -66,7 +69,11 @@ public:
   int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 
-  static List *getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags );
+  class DoubleClickActionDescr : public ActionDescr
+  {
+  public:
+      List *get_action_list( WCFiletype *ft ) const;
+  };
 protected:
   static const char *name;
   void normalmodeddaction( ActionMessage *am );
@@ -89,7 +96,11 @@ public:
   int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 
-  static List *getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags );
+  class ShowActionDescr : public ActionDescr
+  {
+  public:
+      List *get_action_list( WCFiletype *ft ) const;
+  };
 protected:
   static const char *name;
   void normalmodeshow( ActionMessage *am );
@@ -112,7 +123,11 @@ public:
   int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 
-  static List *getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags );
+  class RawShowActionDescr : public ActionDescr
+  {
+  public:
+      List *get_action_list( WCFiletype *ft ) const;
+  };
 protected:
   static const char *name;
   void normalmoderawshow( ActionMessage *am );
@@ -139,7 +154,14 @@ public:
   int getNr() const;
   void setNr( int n );
 
-  static List *getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags );
+  class UserActionDescr : public ActionDescr
+  {
+  public:
+      UserActionDescr( int id );
+      List *get_action_list( WCFiletype *ft ) const;
+  private:
+      int m_id;
+  };
 protected:
   static const char *name;
   int nr;
