@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: chmodop.h,v 1.10 2004/10/27 21:06:08 ralf Exp $ */
+/* $Id: chmodop.h,v 1.11 2005/10/19 18:07:16 ralf Exp $ */
 
 #ifndef CHMODOP_H
 #define CHMODOP_H
@@ -46,7 +46,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual bool save(Datei*);
   virtual const char *getDescription();
   virtual int configure();
@@ -73,7 +73,7 @@ protected:
        tondirs,
        trecursive;
   
-  int normalmodechmod();
+  int normalmodechmod( ActionMessage* );
 };
 
 #endif
