@@ -1,6 +1,6 @@
 /* compregex.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004 Ralf Hoffmann.
+ * Copyright (C) 2004,2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: compregex.h,v 1.2 2004/10/27 21:06:18 ralf Exp $ */
 
 #ifndef COMPREGEX_H
 #define COMPREGEX_H
@@ -37,18 +36,18 @@ public:
   CompRegEx( const CompRegEx &other );
   CompRegEx &operator=( const CompRegEx &other );
 
-  bool match( const char *pattern, const char *str );
+  bool match( const char *pattern, const char *str, bool ignore_case = false );
 private:
 #ifdef HAVE_REGEX
   struct regExpComp_t {
     regex_t patternReg;
     char *pattern;
   };
-  AVLList<std::string,regExpComp_t*> compiled;
+  AVLList<std::string,regExpComp_t*> _compiled, _compiled_nocase;
   void freeCompiled();
-  const struct regExpComp_t &getCompiled( const char *pattern );
+  const struct regExpComp_t &getCompiled( const char *pattern, bool ignore_case );
   size_t maxsize;
-  void freeLast();
+  void freeLast( bool nocase );
 #endif
 };
 
