@@ -22,7 +22,7 @@
 #include "condparser.h"
 #include <aguix/lowlevelfunc.h>
 #include "execlass.h"
-#include "datei.h"
+#include "fileentry.hh"
 #include "worker.h"
 
 struct CondParser::deftokens CondParser::keywords[] = {
