@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: condparser.h,v 1.4 2004/10/27 21:06:24 ralf Exp $ */
+/* $Id: condparser.h,v 1.5 2005/03/08 22:38:26 ralf Exp $ */
 
 #ifndef CONDPARSER_H
 #define CONDPARSER_H
@@ -73,7 +73,8 @@ private:
     TOK_CONTENTSTR,
     TOK_CONTENTNUM,
     TOK_NAME,
-    TOK_FULLNAME
+    TOK_FULLNAME,
+    TOK_ISLOCAL
   };
   static struct deftokens {
     const char *str;
