@@ -319,17 +319,26 @@
      TEXTVIEW_WCP = 545,
      TEXTVIEWHIGHLIGHTED_WCP = 546,
      DIRBOOKMARKOP_WCP = 547,
-     ERROR = 548,
-     ACTIVESIDE_WCP = 549,
-     SHOWFREESPACE_WCP = 550,
-     ACTIVEMODE_WCP = 551,
-     ASK_WCP = 552,
-     SSHALLOW_WCP = 553,
-     FIELD_WIDTH_WCP = 554,
-     QUICKSEARCHENABLED_WCP = 555,
-     FILTEREDSEARCHENABLED_WCP = 556,
-     STRING_WCP = 557,
-     NUM_WCP = 558
+     OPENCONTEXTMENUOP_WCP = 548,
+     RUNCUSTOMACTION_WCP = 549,
+     CUSTOMNAME_WCP = 550,
+     CONTEXTBUTTON_WCP = 551,
+     ACTIVATEMOD_WCP = 552,
+     SCROLLMOD_WCP = 553,
+     CONTEXTMOD_WCP = 554,
+     NONE_WCP = 555,
+     CUSTOMACTION_WCP = 556,
+     ERROR = 557,
+     ACTIVESIDE_WCP = 558,
+     SHOWFREESPACE_WCP = 559,
+     ACTIVEMODE_WCP = 560,
+     ASK_WCP = 561,
+     SSHALLOW_WCP = 562,
+     FIELD_WIDTH_WCP = 563,
+     QUICKSEARCHENABLED_WCP = 564,
+     FILTEREDSEARCHENABLED_WCP = 565,
+     STRING_WCP = 566,
+     NUM_WCP = 567
    };
 #endif
 /* Tokens.  */
@@ -623,17 +632,26 @@
 #define TEXTVIEW_WCP 545
 #define TEXTVIEWHIGHLIGHTED_WCP 546
 #define DIRBOOKMARKOP_WCP 547
-#define ERROR 548
-#define ACTIVESIDE_WCP 549
-#define SHOWFREESPACE_WCP 550
-#define ACTIVEMODE_WCP 551
-#define ASK_WCP 552
-#define SSHALLOW_WCP 553
-#define FIELD_WIDTH_WCP 554
-#define QUICKSEARCHENABLED_WCP 555
-#define FILTEREDSEARCHENABLED_WCP 556
-#define STRING_WCP 557
-#define NUM_WCP 558
+#define OPENCONTEXTMENUOP_WCP 548
+#define RUNCUSTOMACTION_WCP 549
+#define CUSTOMNAME_WCP 550
+#define CONTEXTBUTTON_WCP 551
+#define ACTIVATEMOD_WCP 552
+#define SCROLLMOD_WCP 553
+#define CONTEXTMOD_WCP 554
+#define NONE_WCP 555
+#define CUSTOMACTION_WCP 556
+#define ERROR 557
+#define ACTIVESIDE_WCP 558
+#define SHOWFREESPACE_WCP 559
+#define ACTIVEMODE_WCP 560
+#define ASK_WCP 561
+#define SSHALLOW_WCP 562
+#define FIELD_WIDTH_WCP 563
+#define QUICKSEARCHENABLED_WCP 564
+#define FILTEREDSEARCHENABLED_WCP 565
+#define STRING_WCP 566
+#define NUM_WCP 567
 
 
 
@@ -645,7 +663,7 @@ typedef union YYSTYPE {
   char *strptr;
 } YYSTYPE;
 /* Line 1447 of yacc.c.  */
-#line 649 "configparser.tab.h"
+#line 667 "configparser.tab.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
