@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: configtokens.cc,v 1.24 2005/12/11 19:25:53 ralf Exp $ */
 
 #include "wdefines.h"
 #include "simplelist.hh"
@@ -321,7 +320,16 @@ struct mytoken tokenlist[]={
   { TEXTVIEW_WCP, "textview" },
   { TEXTVIEWHIGHLIGHTED_WCP, "textviewhighlighted" },
   { FILTEREDSEARCHENABLED_WCP, "filteredsearchenabled"},
-  { DIRBOOKMARKOP_WCP, "dirbookmarkop" }
+  { DIRBOOKMARKOP_WCP, "dirbookmarkop" },
+  { OPENCONTEXTMENUOP_WCP, "opencontextmenuop" },
+  { CONTEXTBUTTON_WCP, "contextbutton" },
+  { ACTIVATEMOD_WCP, "activatemod" },
+  { SCROLLMOD_WCP, "scrollmod" },
+  { CONTEXTMOD_WCP, "contextmod" },
+  { NONE_WCP, "none" },
+  { RUNCUSTOMACTION_WCP, "runcustomaction" },
+  { CUSTOMNAME_WCP, "customname" },
+  { CUSTOMACTION_WCP, "customaction" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
