@@ -145,7 +145,7 @@ CopyOp::normalmodecopy( ActionMessage *am )
   ListerMode *lm1=NULL;
   NM_specialsourceExt *specialsource=NULL;
   bool do_request,cont=true;
-  char *tstr,*tstr2,*dest=NULL;
+  char *tstr2,*dest=NULL;
   
   if(am->mode==am->AM_MODE_DNDACTION) {
     lm1 = am->dndmsg->getSourceMode();
@@ -195,13 +195,11 @@ CopyOp::normalmodecopy( ActionMessage *am )
       copyorder.source=copyorder.NM_SPECIAL;
       copyorder.sources=new std::list<NM_specialsourceExt*>;
       specialsource = new NM_specialsourceExt( am->dndmsg->getFE() );
-      specialsource->row=-1;
       copyorder.sources->push_back(specialsource);
     } else if(am->mode==am->AM_MODE_SPECIAL) {
       copyorder.source=copyorder.NM_SPECIAL;
       copyorder.sources=new std::list<NM_specialsourceExt*>;
       specialsource = new NM_specialsourceExt( am->getFE() );
-      specialsource->row=-1;
       copyorder.sources->push_back(specialsource);
     } else
       copyorder.source=copyorder.NM_ALLENTRIES;
@@ -222,7 +220,7 @@ CopyOp::normalmodecopy( ActionMessage *am )
     if(trequest_dest==true)
       do_request=true;
     else if(tsame_dir==true) {
-      tstr = nm1->getCurrentDir();
+      const char *tstr = nm1->getCurrentDir();
       if(tstr!=NULL)
         dest=dupstring(tstr);
     } else if(am->mode==am->AM_MODE_DNDACTION) {
@@ -231,7 +229,7 @@ CopyOp::normalmodecopy( ActionMessage *am )
       else dest=NULL;
     } else {
       if(nm2!=NULL) {
-        tstr = nm2->getCurrentDir();
+        const char *tstr = nm2->getCurrentDir();
         if(tstr!=NULL)
           dest=dupstring(tstr);
         else
@@ -267,7 +265,7 @@ CopyOp::normalmodecopy( ActionMessage *am )
       /* if dest starts with no slash then take it as local dir
          so add currentDir */
       if(dest[0]!='/') {
-        tstr=catstring(nm1->getCurrentDir(),"/");
+        char *tstr=catstring(nm1->getCurrentDir(),"/");
         tstr2=catstring(tstr,dest);
         _freesafe(tstr);
         _freesafe(dest);
