@@ -103,7 +103,7 @@ CreateSymlinkOp::normalmodecreatesl( ActionMessage *am )
   ListerMode *lm1=NULL;
   NM_specialsourceExt *specialsource=NULL;
   bool cont=true;
-  char *tstr,*dest=NULL;
+  char *dest=NULL;
   struct NM_createsymlinkorder cslorder;
   bool takesamedir;
   
@@ -148,13 +148,11 @@ CreateSymlinkOp::normalmodecreatesl( ActionMessage *am )
       cslorder.source=cslorder.NM_SPECIAL;
       cslorder.sources=new std::list<NM_specialsourceExt*>;
       specialsource = new NM_specialsourceExt( am->dndmsg->getFE() );
-      specialsource->row=-1;
       cslorder.sources->push_back(specialsource);
     } else if(am->mode==am->AM_MODE_SPECIAL) {
       cslorder.source=cslorder.NM_SPECIAL;
       cslorder.sources=new std::list<NM_specialsourceExt*>;
       specialsource = new NM_specialsourceExt( am->getFE() );
-      specialsource->row=-1;
       cslorder.sources->push_back(specialsource);
     } else
       cslorder.source=cslorder.NM_ALLENTRIES;
@@ -167,7 +165,7 @@ CreateSymlinkOp::normalmodecreatesl( ActionMessage *am )
       takesamedir=false;
     } else if(tsame_dir==false) {
       if(nm2!=NULL) {
-        tstr = nm2->getCurrentDir();
+        const char *tstr = nm2->getCurrentDir();
         if(tstr!=NULL) {
           dest=dupstring(tstr);
           takesamedir=false;
@@ -176,7 +174,7 @@ CreateSymlinkOp::normalmodecreatesl( ActionMessage *am )
     }
 
     if(takesamedir==true) {
-      tstr = nm1->getCurrentDir();
+      const char *tstr = nm1->getCurrentDir();
       if(tstr!=NULL)
         dest=dupstring(tstr);
     }
