@@ -1,6 +1,6 @@
 /* dnd.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,18 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: dnd.h,v 1.8 2004/12/12 21:56:38 ralf Exp $ */
 
 #ifndef DND_H
 #define DND_H
 
 #include "wdefines.h"
 #include <aguix/message.h>
-#include "datei.h"
 
 class Lister;
 class ListerMode;
 class Worker;
+class FileEntry;
 
 class DNDMsg
 {
