@@ -37,24 +37,33 @@ ExeClass::ExeClass( execlass_execute_t exetype, Worker *w )
   tmpfile = Datei::createTMPName();
   tmpoutput = Datei::createTMPName();
   tmperror = Datei::createTMPName();
-  fp = worker_fopen( tmpoutput, "w" );
-  if ( fp != NULL ) {
-    /* be sure the output can only be changed be use */
-    worker_fclose( fp );
-    worker_chmod( tmpoutput, S_IRUSR | S_IWUSR | S_IXUSR );
-  }
-  fp = worker_fopen( tmperror, "w" );
-  if ( fp != NULL ) {
-    /* be sure the output can only be changed be use */
-    worker_fclose( fp );
-    worker_chmod( tmperror, S_IRUSR | S_IWUSR );
-  }
-  fp = worker_fopen( tmpfile, "w" );
-  if ( fp != NULL ) {
-    worker_chmod( tmpfile, S_IRUSR | S_IWUSR | S_IXUSR );
-    if ( fprintf( fp, "#! /bin/sh\n\n" ) < 0 ) {
+
+  if ( tmpoutput != NULL ) {
+    fp = worker_fopen( tmpoutput, "w" );
+    if ( fp != NULL ) {
+      /* be sure the output can only be changed be use */
       worker_fclose( fp );
-      fp = NULL;
+      worker_chmod( tmpoutput, S_IRUSR | S_IWUSR | S_IXUSR );
+    }
+  }
+
+  if ( tmperror != NULL ) {
+    fp = worker_fopen( tmperror, "w" );
+    if ( fp != NULL ) {
+      /* be sure the output can only be changed be use */
+      worker_fclose( fp );
+      worker_chmod( tmperror, S_IRUSR | S_IWUSR );
+    }
+  }
+  
+  if ( tmpfile != NULL ) {
+    fp = worker_fopen( tmpfile, "w" );
+    if ( fp != NULL ) {
+      worker_chmod( tmpfile, S_IRUSR | S_IWUSR | S_IXUSR );
+      if ( fprintf( fp, "#! /bin/sh\n\n" ) < 0 ) {
+        worker_fclose( fp );
+        fp = NULL;
+      }
     }
   }
   lasterror = 0;
@@ -65,12 +74,21 @@ ExeClass::~ExeClass()
   if ( fp != NULL ) {
     worker_fclose( fp );
   }
-  worker_unlink( tmpfile );
-  _freesafe( tmpfile );
-  worker_unlink( tmpoutput );
-  _freesafe( tmpoutput );
-  worker_unlink( tmperror );
-  _freesafe( tmperror );
+
+  if ( tmpfile != NULL ) {
+    worker_unlink( tmpfile );
+    _freesafe( tmpfile );
+  }
+
+  if ( tmpoutput != NULL ) {
+    worker_unlink( tmpoutput );
+    _freesafe( tmpoutput );
+  }
+
+  if ( tmperror != NULL ) {
+    worker_unlink( tmperror );
+    _freesafe( tmperror );
+  }
 }
 
 /* this method adds a command to the shell-script
@@ -776,7 +794,7 @@ int ExeClass::readErrorOutput( std::string &return_str, int maxsize )
   if ( maxsize < 1 )
     maxsize = 1;
 
-  if ( d.open( tmperror ) == 0 ) {
+  if ( tmperror != NULL && d.open( tmperror ) == 0 ) {
     while ( maxsize > 0 ) {
       l = a_min( (int)sizeof( buf ) - 1, maxsize );
       r = d.read( buf, l );
