@@ -29,7 +29,7 @@
 bool FileViewer::last_wrap_mode = false;
 bool FileViewer::last_showlinenumbers_mode = false;
 
-FileViewer::FileViewer()
+FileViewer::FileViewer() : win( NULL )
 {
 }
 
@@ -55,7 +55,7 @@ void FileViewer::view( const std::list<std::string> &filelist, int initial_line_
   std::list<std::string>::const_iterator it1;
   int w, h, sw, sh;
 
-  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocaleCom( 49 ) );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocaleCom( 49 ) );
   win->create();
   /*  if ( aguix->getTransientWindow() != NULL ) {
     win->setTransientForAWindow( aguix->getTransientWindow() );
@@ -70,14 +70,19 @@ void FileViewer::view( const std::list<std::string> &filelist, int initial_line_
   ac1_1->setMaxSpace( 5 );
   ac1_1->setBorderWidth( 0 );
   ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 404 ), 1 ), 0, 0, AContainer::CFIXNR );
-  Text *fnt = (Text*)ac1_1->add( new Text( aguix, 0, 0, "", 1 ), 1, 0, cincwnr );
+  Text *fnt = (Text*)ac1_1->add( new Text( aguix, 0, 0, "", 1 ), 1, 0, AContainer::ACONT_MINH + AContainer::ACONT_MAXH );
   Button *readmoreb = (Button*)ac1_1->add( new Button( aguix, 0, 0, catalog.getLocale( 763 ), 1, 0, 0 ),
                                            2, 0, cfix );
   it1 = filelist.begin();
   
   AFontWidth lencalc( aguix, NULL );
 
-  buildTextView( *it1, &ts, &tv, ac1, fnt, lencalc );
+  if ( buildTextView( *it1, &ts, &tv, ac1, fnt, lencalc ) != 0 ) {
+      delete win;
+      if ( ts != NULL ) delete ts;
+      return;
+  }
+
   ac1->readLimits();
   ac1_1->readLimits();
 
@@ -166,7 +171,7 @@ void FileViewer::view( const std::list<std::string> &filelist, int initial_line_
 		  it1--;
 		  buildTextView( *it1, &ts, &tv, ac1 );*/
 	  } else if ( msg->button.button == jumplineb ) {
-            jumpToLine( *win, *tv );
+            jumpToLine( *tv );
 	  } else if ( msg->button.button == readmoreb ) {
               ts->readMore();
               tv->textStorageChanged();
@@ -191,7 +196,7 @@ void FileViewer::view( const std::list<std::string> &filelist, int initial_line_
 	        break;
               case XK_l:
                 if ( ( msg->key.keystate & ( ControlMask | Mod1Mask ) ) != 0 ) {
-                  jumpToLine( *win, *tv );
+                  jumpToLine( *tv );
                 }
                 break;
               case XK_r:
@@ -216,22 +221,23 @@ void FileViewer::view( const std::list<std::string> &filelist, int initial_line_
   if ( ts != NULL ) delete ts;
 }
 
-void FileViewer::buildTextView( const std::string &filename,
-                                TextStorageFile **ts,
-                                TextView **tv,
-                                AContainer *ac1,
-                                class Text *fnt,
-                                AWidth &lencalc )
+int FileViewer::buildTextView( const std::string &filename,
+                               TextStorageFile **ts,
+                               TextView **tv,
+                               AContainer *ac1,
+                               class Text *fnt,
+                               AWidth &lencalc )
 {
   AGUIX *aguix = Worker::getAGUIX();
   const int cmin = AContainer::ACONT_MINH +
                    AContainer::ACONT_MINW;
   
-  if ( ts == NULL || tv == NULL || ac1 == NULL ) return;
+  if ( ts == NULL || tv == NULL || ac1 == NULL ) return 1;
 
   NWC::FSEntry fse( filename );
   int file_length = 0;
   int initial_size = ( last_wrap_mode == true ) ? ( 64 * 1024 ) : ( 2 * 1024 * 1024 );
+  bool continue_viewing = true;
   
   if ( fse.isReg() == true ) {
       if ( fse.isLink() == false ) {
@@ -243,6 +249,7 @@ void FileViewer::buildTextView( const std::string &filename,
 
   if ( file_length > initial_size ) {
       std::string l1, l2;
+      int cancel_button;
 
       l1 = AGUIXUtils::bytes_to_human_readable( file_length );
       l2 = AGUIXUtils::bytes_to_human_readable( initial_size );
@@ -258,22 +265,38 @@ void FileViewer::buildTextView( const std::string &filename,
       if ( last_wrap_mode == true ) {
           buttontext += "|";
           buttontext += catalog.getLocale( 767 );
+
+          cancel_button = 3;
+      } else {
+          cancel_button = 2;
       }
 
+      buttontext += "|";
+      buttontext += catalog.getLocale( 8 );
+
       int erg = Worker::getRequester()->request( catalog.getLocale( 123 ),
                                                  textstr,
                                                  buttontext.c_str(),
-                                                 Requester::REQUEST_CANCELWITHLEFT );
+                                                 win,
+                                                 Requester::REQUEST_NONE );
       if ( erg == 1 ) {
           initial_size = file_length;
+      } else if ( erg == cancel_button ) {
+          continue_viewing = false;
       } else if ( erg == 2 ) {
           initial_size = file_length;
           last_wrap_mode = false;
       }
       _freesafe( textstr );
   }
+
+  if ( continue_viewing == false ) {
+      return 2;
+  }
   
-  delete *tv;
+  if ( *tv != NULL ) {
+      delete *tv;
+  }
   *ts = new TextStorageFile( filename, lencalc, initial_size );
   *tv = new TextView( aguix, 0, 0, 100, 100, 0, "", **ts );
   (*tv)->setDisplayFocus( true );
@@ -282,6 +305,8 @@ void FileViewer::buildTextView( const std::string &filename,
   if ( fnt != NULL ) fnt->setText( filename.c_str() );
   ac1->rearrange();
   (*tv)->show();
+
+  return 0;
 }
 
 void FileViewer::setLineWrap( bool nv )
@@ -304,7 +329,7 @@ bool FileViewer::getShowLineNumbers()
   return last_showlinenumbers_mode;
 }
 
-void FileViewer::jumpToLine( AWindow &win, TextView &tv )
+void FileViewer::jumpToLine( TextView &tv )
 {
   int erg;
   std::string buttons;
@@ -315,11 +340,11 @@ void FileViewer::jumpToLine( AWindow &win, TextView &tv )
   buttons += catalog.getLocale( 8 );
 
   //TODO use current line number as default but I need the interface in tv for this first
-  erg = win.string_request( catalog.getLocale( 123 ),
-                            catalog.getLocale( 717 ),
-                            "",
-                            buttons.c_str(),
-                            &return_str );
+  erg = win->string_request( catalog.getLocale( 123 ),
+                             catalog.getLocale( 717 ),
+                             "",
+                             buttons.c_str(),
+                             &return_str );
   if ( erg == 0 && return_str != NULL ) {
     int line_nr = 0;
     line_nr = atoi( return_str ) - 1;
