@@ -1,6 +1,6 @@
 /* fontreq.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -64,7 +64,7 @@ FontRequester::~FontRequester()
   delete fontlist;
 }
 
-int FontRequester::request(char *xname,char**return_xname)
+int FontRequester::request(const char *xname,char**return_xname)
 {
   char *rstr;
   int act_font=0,act_fontsize=0;
@@ -92,7 +92,7 @@ int FontRequester::request(char *xname,char**return_xname)
   win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 204 ) );
   win->create();
 
-  ac1 = win->setContainer( new AContainer( win, 1, 6 ), true );
+  ac1 = win->setContainer( new AContainer( win, 1, 7 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
@@ -116,7 +116,7 @@ int FontRequester::request(char *xname,char**return_xname)
 						       aguix->getCharHeight() * 10,
 						       1 ), 1, 0, cmin );
 
-  etext = (Text*)ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 382 ), 1 ), 0, 2, cincwnr );
+  example_sg = (StringGadget*)ac1->add( new StringGadget( aguix, 0, 0, 100, catalog.getLocale( 382 ), 0 ), 0, 2, cincw );
 
   ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
   ac1_2->setMinSpace( 5 );
@@ -126,9 +126,19 @@ int FontRequester::request(char *xname,char**return_xname)
   ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 383 ), 1 ), 0, 0, cfix );
   ftext = (Text*)ac1_2->add( new Text( aguix, 0, 0, "", 1 ), 1, 0, cincwnr );
 
-  xb = (Button*)ac1->add( new Button( aguix, 0, 0, catalog.getLocale( 381 ), 1, 0, 0 ), 0, 4, cincw );
+  AContainer *ac1_4 = ac1->add( new AContainer( win, 4, 1 ), 0, 4 );
+  ac1_4->setMinSpace( 5 );
+  ac1_4->setMaxSpace( 5 );
+  ac1_4->setBorderWidth( 0 );
 
-  AContainer *ac1_3 = ac1->add( new AContainer( win, 2, 1 ), 0, 5 );
+  ac1_4->add( new Text( aguix, 0, 0, catalog.getLocale( 713 ), 1 ), 0, 0, cfix );
+  missingtext = (Text*)ac1_4->add( new Text( aguix, 0, 0, "     ", 1 ), 1, 0, cincwnr );
+  Button *missing_help_b = (Button*)ac1_4->add( new Button( aguix, 0, 0, catalog.getLocale( 483 ), 1, 0, 0 ),
+                                                3, 0, cfix );
+
+  xb = (Button*)ac1->add( new Button( aguix, 0, 0, catalog.getLocale( 381 ), 1, 0, 0 ), 0, 5, cincw );
+
+  AContainer *ac1_3 = ac1->add( new AContainer( win, 2, 1 ), 0, 6 );
   ac1_3->setMinSpace( 5 );
   ac1_3->setMaxSpace( -1 );
   ac1_3->setBorderWidth( 0 );
@@ -229,12 +239,15 @@ int FontRequester::request(char *xname,char**return_xname)
 	    endmode=0;
           } else if(msg->button.button==cb) {
             endmode=1;
+          } else if ( msg->button.button == missing_help_b ) {
+            req->request( catalog.getLocale( 124 ), catalog.getLocale( 714 ),
+                          catalog.getLocale( 11 ) );
           } else if(msg->button.button==xb) {
             buttonstr=(char*)_allocsafe(strlen(catalog.getLocale(11))+1+
                                         strlen(catalog.getLocale(8))+1);
             sprintf(buttonstr,"%s|%s",catalog.getLocale(11),
                                       catalog.getLocale(8));
-            if(req->string_request(catalog.getLocale(123),catalog.getLocale(381),"",buttonstr,&rstr)==0) {
+            if(req->string_request(catalog.getLocale(123),catalog.getLocale(381),ftext->getText(),buttonstr,&rstr)==0) {
               if(aguix->getFont(rstr)!=NULL) {
                 // search for existing entry
                 if(findfont(rstr,&ni,&nj)==0) {
@@ -372,6 +385,7 @@ void FontRequester::updatefont()
   int i,j;
   char *tstr,*buffer;
   struct request_fonts *font1;
+  std::string xfontname;
   
   trow = lv->getActiveRow();
   if ( lv->isValidRow( trow ) == true ) {
@@ -386,18 +400,28 @@ void FontRequester::updatefont()
         if(font1->type==request_fonts::SCALEABLE) {
           buffer = (char*)_allocsafe( strlen( tstr ) + A_BYTESFORNUMBER( int ) + 1 );
           sprintf(buffer,tstr,getsize(i,j));
-          etext->setFont(buffer);
-          etext->redraw();
+          example_sg->setFont( buffer );
+          xfontname = buffer;
           ftext->setText(buffer);
           _freesafe(buffer);
         } else {
-          etext->setFont(tstr);
-          etext->redraw();
+          example_sg->setFont( tstr );
+          xfontname = tstr;
           ftext->setText(tstr);
         }
-	ac1->setMinHeight( etext->getHeight(), 0, 2 );
-	ac1->setMaxHeight( etext->getHeight(), 0, 2 );
-	ac1->setMinWidth( etext->getWidth(), 0, 2 );
+
+        missingtext->setText( "" );
+        if ( xfontname.length() > 0 ) {
+          AGUIXFont *font = aguix->getFont( xfontname.c_str() );
+          if ( font != NULL ) {
+            char numbuf[ A_BYTESFORNUMBER( int ) ];
+            sprintf( numbuf, "%d", font->getNumberOfMissingCharsets() );
+            missingtext->setText( numbuf );
+          }
+        }
+        example_sg->changeHeightForCurFont();
+  	ac1->setMinHeight( example_sg->getHeight(), 0, 2 );
+	ac1->setMaxHeight( example_sg->getHeight(), 0, 2 );
 	ac1_2->readLimits();
 	win->contMaximize( true );
       }
