@@ -86,15 +86,12 @@ int FunctionProto::run( WPUContext *wpu, ActionMessage *msg )
 
 ActionMessage::ActionMessage( Worker *w)
 {
-  flags=NULL;
   mode=AM_MODE_NORMAL;
   startLister=NULL;
   dndmsg = NULL;
   fe = NULL;
   worker = w;
 
-  getActionList = NULL;
-  getActionListID = 0;
   filetype = NULL;
 }
 
