@@ -1,6 +1,6 @@
 /* functionproto.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,21 +18,29 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: functionproto.h,v 1.15 2005/10/19 18:04:50 ralf Exp $ */
 
 #ifndef FUNCTIONPROTO_H
 #define FUNCTIONPROTO_H
 
 #include "wdefines.h"
+#include <aguix/refcount.hh>
 
 class Datei;
 class Worker;
 class AGUIX;
-class WCGlobalFlags;
 class Lister;
 class WPUContext;
 class List;
 
+class ActionDescr
+{
+ public:
+    ActionDescr() {}
+    virtual ~ActionDescr() {}
+
+    virtual List *get_action_list( class WCFiletype *ft ) const = 0;
+};
+
 class ActionMessage
 {
 public:
@@ -41,8 +49,6 @@ public:
   ActionMessage( const ActionMessage &other );
   ActionMessage &operator=( const ActionMessage &other );
 
-  WCGlobalFlags *flags;
-  
   typedef enum {AM_MODE_NORMAL,
                 AM_MODE_ONLYACTIVE,
                 AM_MODE_DNDACTION,
@@ -51,8 +57,7 @@ public:
   Lister *startLister;
   const class DNDMsg *dndmsg;
   class WCFiletype *filetype;
-  class List *(*getActionList)( class WCFiletype *, int id, WCGlobalFlags **return_flags );
-  int getActionListID;
+  RefCount<ActionDescr> m_action_descr;
   
   Worker *getWorker() const;
   const class FileEntry *getFE() const;
