@@ -1,6 +1,6 @@
 /* goftpop.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2005 Ralf Hoffmann.
+ * Copyright (C) 2005-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,12 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: goftpop.cc,v 1.4 2005/10/19 18:04:46 ralf Exp $ */
 
 #include "goftpop.h"
 #include "listermode.h"
 #include "normalmode.h"
 #include "worker.h"
+#include "avfssupport.hh"
 
 const char *GoFTPOp::name = "GoFTPOp";
 
@@ -35,6 +35,7 @@ GoFTPOp::GoFTPOp() : FunctionProto()
   host = "";
   user = "";
   pass = "";
+  avfs_module = "ftp";
   hasConfigure = true;
 
   pw_stored = false;
@@ -53,6 +54,7 @@ GoFTPOp::duplicate() const
   ta->setHost( host );
   ta->setUser( user );
   ta->setPass( pass );
+  ta->setAVFSModule( avfs_module );
   ta->setAlwaysStorePW( always_store_pw );
   return ta;
 }
@@ -86,6 +88,7 @@ GoFTPOp::run( WPUContext *wpu, ActionMessage *msg )
     thost = host;
     tuser = user;
     tpass = pass;
+    tavfs_module = avfs_module;
     talways_store_pw = always_store_pw;
   }
   
@@ -95,7 +98,9 @@ GoFTPOp::run( WPUContext *wpu, ActionMessage *msg )
       req->request( catalog.getLocale( 124 ), catalog.getLocale( 625 ), catalog.getLocale( 11 ) );
     } else {
       if ( ( pw_stored == false ) || ( talways_store_pw == true ) ) {
-	str1 = "/#ftp_ctl:";
+        str1 = "/#";
+        str1 += tavfs_module;
+        str1 += "_ctl:";
 	str1 += tuser;
 	str1 += "@";
 	str1 += thost;
@@ -110,7 +115,9 @@ GoFTPOp::run( WPUContext *wpu, ActionMessage *msg )
       }
 
       if ( tdontenterftp == false ) {
-	str1 = "/#ftp:";
+        str1 = "/#";
+        str1 += tavfs_module;
+	str1 += ":";
 	str1 += tuser;
 	str1 += "@";
 	str1 += thost;
@@ -144,6 +151,7 @@ GoFTPOp::save(Datei *fh)
   fh->configPutPairString( "username", user.c_str() );
   fh->configPutPairString( "password", pass.c_str() );
   fh->configPutPairBool( "alwaysstorepw", always_store_pw );
+  //TODO store avfs_module
   return true;
 }
 
@@ -165,7 +173,7 @@ GoFTPOp::doconfigure(int mode)
   AGUIX *aguix = Worker::getAGUIX();
   Button *okb,*cancelb;
   AWindow *win;
-  ChooseButton *cb1,*rfcb=NULL, *cb2;
+  ChooseButton *cb1,*rfcb=NULL, *cb2, *cb_anon;
   StringGadget *sgh, *sgu, *sgp;
   AGMessage *msg;
   int endmode=-1;
@@ -180,14 +188,18 @@ GoFTPOp::doconfigure(int mode)
                    AContainer::ACONT_MAXH +
                    AContainer::ACONT_MAXW;
   Requester *req = Worker::getRequester();
+  std::vector<std::string> module_list;
+  CycleButton *cycb_avfs = NULL;
   
+  module_list = getAvailModules();
+
   tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( catalog.getLocaleCom( 48 ) ) + 1 );
   sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 48 ) );
   win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe( tstr );
 
-  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 7 ), true );
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 9 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
@@ -217,19 +229,43 @@ GoFTPOp::doconfigure(int mode)
   sgp->setPasswordMode( true );
   sgp->setText( pass.c_str() );
 
+  cb_anon = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, false,
+                                                       catalog.getLocale( 755 ), LABEL_RIGHT, 1, 0 ),
+                                     0, 3, cincwnr );
+
   cb1 = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( dontenterftp == true ) ? 1 : 0,
 						   catalog.getLocale( 623 ), LABEL_RIGHT, 1, 0 ),
-				 0, 3, cincwnr );
+				 0, 4, cincwnr );
   cb2 = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( always_store_pw == true ) ? 1 : 0,
 						   catalog.getLocale( 627 ), LABEL_RIGHT, 1, 0 ),
-				 0, 4, cincwnr );
+				 0, 5, cincwnr );
+
+  if ( module_list.size() > 1 ) {
+      AContainer *ac1_6 = ac1->add( new AContainer( win, 2, 1 ), 0, 6 );
+      ac1_6->setMinSpace( 5 );
+      ac1_6->setMaxSpace( 5 );
+      ac1_6->setBorderWidth( 0 );
+      //TODO translate
+      ac1_6->add( new Text( aguix, 0, 0, "AVFS module:"/*catalog.getLocale( 621 )*/, 1 ), 0, 0, cfix );
+      cycb_avfs = (CycleButton*)ac1_6->add( new CycleButton( aguix, 0, 0, 50, 1, 0, 0 ),
+                                                         1, 0, AContainer::CINCWNR );
+
+      for ( std::vector<std::string>::iterator it1 = module_list.begin();
+            it1 != module_list.end();
+            it1++ ) {
+          cycb_avfs->addOption( it1->c_str() );
+      }
+      cycb_avfs->resize( cycb_avfs->getMaxSize(), cycb_avfs->getHeight() );
+      ac1_6->readLimits();
+  }
+
   if ( mode == 0 ) {
     rfcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( requestflags == true ) ? 1 : 0,
 						      catalog.getLocale( 294 ), LABEL_RIGHT, 1, 0 ),
-				    0, 5, cincwnr );
+				    0, 7, cincwnr );
   }
 
-  AContainer *ac1_5 = ac1->add( new AContainer( win, 2, 1 ), 0, 6 );
+  AContainer *ac1_5 = ac1->add( new AContainer( win, 2, 1 ), 0, 8 );
   ac1_5->setMinSpace( 5 );
   ac1_5->setMaxSpace( -1 );
   ac1_5->setBorderWidth( 0 );
@@ -278,6 +314,23 @@ GoFTPOp::doconfigure(int mode)
             }
           }
           break;
+        case AG_CHOOSECLICKED:
+            if ( msg->choose.button == cb_anon ) {
+                if ( msg->choose.state == true ) {
+                    sgu->setText( "anonymous" );
+                    sgp->setText( "ano@nym.ous" );
+                    sgp->setPasswordMode( false );
+                } else {
+                    sgp->setPasswordMode( true );
+                }
+            }
+            break;
+        case AG_STRINGGADGET_CONTENTCHANGE:
+            if ( msg->stringgadget.sg == sgu ) {
+                sgp->setPasswordMode( true );
+                cb_anon->setState( false );
+            }
+            break;
       }
       aguix->ReplyMessage( msg );
     }
@@ -291,6 +344,14 @@ GoFTPOp::doconfigure(int mode)
       thost = sgh->getText();
       tuser = sgu->getText();
       tpass = sgp->getText();
+
+      tavfs_module = "ftp";
+      if ( cycb_avfs != NULL ) {
+          if ( cycb_avfs->getSelectedOption() >= 0 &&
+               cycb_avfs->getSelectedOption() < static_cast<int>( module_list.size() ) ) {
+              tavfs_module = module_list[ cycb_avfs->getSelectedOption() ];
+          }
+      }
       sgp->setText( "" );
     } else {
       dontenterftp = cb1->getState();
@@ -310,6 +371,15 @@ GoFTPOp::doconfigure(int mode)
 	  }
 	}
       }
+
+      std::string str2 = "ftp";
+      if ( cycb_avfs != NULL ) {
+          if ( cycb_avfs->getSelectedOption() >= 0 &&
+               cycb_avfs->getSelectedOption() < static_cast<int>( module_list.size() ) ) {
+              str2 = module_list[ cycb_avfs->getSelectedOption() ];
+          }
+      }
+      setAVFSModule( str2 );
       sgp->setText( "" );
     }
   }
@@ -343,7 +413,34 @@ void GoFTPOp::setPass( std::string s1 )
   pass = s1;
 }
 
+void GoFTPOp::setAVFSModule( const std::string &s1 )
+{
+  avfs_module = s1;
+}
+
 void GoFTPOp::setAlwaysStorePW( bool nv )
 {
   always_store_pw = nv;
 }
+
+std::vector<std::string> GoFTPOp::getAvailModules()
+{
+    std::vector<std::string> l, avail_modules;
+    std::vector<std::string>::iterator it1;
+    
+    // ftp is always available
+    l.push_back( "ftp" );
+
+    avail_modules = AVFSSupport::getAVFSModules();
+    
+    for ( it1 = avail_modules.begin();
+          it1 != avail_modules.end();
+          it1++ ) {
+        if ( *it1 == "ucftp" ) {
+            l.push_back( "ucftp" );
+            break;
+        }
+    }
+    
+    return l;
+}
