@@ -26,6 +26,7 @@
 #include "wdefines.h"
 #include "functionproto.h"
 #include <string>
+#include <vector>
 
 class GoFTPOp:public FunctionProto
 {
@@ -54,20 +55,25 @@ public:
   void setUser( std::string );
   void setPass( std::string );
   void setAlwaysStorePW( bool );
+  void setAVFSModule( const std::string & );
   static const char *name;
 protected:
   // Infos to save
 
   bool requestflags, dontenterftp, always_store_pw;
   std::string host, user, pass;
+  std::string avfs_module;
   
   // temp variables
   //  Lister *startlister,*endlister;
   
   bool tdontenterftp, talways_store_pw;
   std::string thost, tuser, tpass;
+  std::string tavfs_module;
 
   bool pw_stored;
+
+  std::vector<std::string> getAvailModules();
 };
 
 #endif
