@@ -145,7 +145,8 @@ InternalViewOp::run( WPUContext *wpu, ActionMessage *msg )
 
     if ( filelist.size() > 0 ) {
       msg->getWorker()->setWaitCursor();
-      FileViewer::view( filelist );
+      FileViewer fv;
+      fv.view( filelist );
       msg->getWorker()->unsetWaitCursor();
     }
   }
