@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: makedirop.h,v 1.7 2004/10/27 21:07:58 ralf Exp $ */
+/* $Id: makedirop.h,v 1.8 2005/10/19 18:03:59 ralf Exp $ */
 
 #ifndef MAKEDIROP_H
 #define MAKEDIROP_H
@@ -40,7 +40,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 protected:
   static const char *name;
