@@ -1,6 +1,6 @@
 /* nmrowdata.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2003-2004 Ralf Hoffmann.
+ * Copyright (C) 2003-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,14 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: nmrowdata.h,v 1.4 2004/12/12 21:53:36 ralf Exp $ */
 
 #ifndef NMROWDATA_H
 #define NMROWDATA_H
 
 #include "wdefines.h"
 #include <aguix/fieldlvrowdata.h>
-#include "datei.h"
+
+class FileEntry;
 
 class NMRowData : public FieldLVRowData
 {
