@@ -1,6 +1,6 @@
 /* nmspecialsourceext.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,8 +28,6 @@ NM_specialsourceExt::NM_specialsourceExt( const FileEntry *tfe )
   } else {
     fe = new FileEntry( *tfe );
   }
-  row = -1;
-  //  cod = NULL;
 }
 
 NM_specialsourceExt::~NM_specialsourceExt()
