@@ -32,6 +32,7 @@
 #include <aguix/request.h>
 #include <aguix/mutex.h>
 #include <aguix/condvar.h>
+#include <aguix/refcount.hh>
 #include "listermode.h"
 #include "datei.h"
 #include "copyop.h"
@@ -285,6 +286,8 @@ public:
 
   bool filteredSearchActive() const;
   void deactivateFilteredSearch();
+  
+  void openContextMenu();
 protected:
   /*
    * NM_specialsourceInt always stores a pointer to a FE
@@ -524,7 +527,10 @@ protected:
 	if ( fg != NULL ) delete [] fg;
 	if ( bg != NULL ) delete [] bg;
         if ( name != NULL ) _freesafe( name );
+        if ( ft_index != NULL ) delete ft_index;
       }
+      ft_recres_list_t( const ft_recres_list_t &other );
+      ft_recres_list_t &operator=( const ft_recres_list_t &other );
     };
     
     ft_recres_list();
@@ -661,6 +667,15 @@ protected:
 
   int buildSpecialSourceIntList( const std::list<NM_specialsourceExt*> &inlist,
                                  std::list<NM_specialsourceInt*> &outlist );
+  
+  class PopUpMenu *m_lv_popup_menu;
+  std::auto_ptr<FileEntry> m_entry_for_popup;
+
+  std::map<int, RefCount<ActionDescr> > m_popup_descr;
+
+  void lv_pressed( int row, bool open_under_mouse = true );
+  void buildPopUpMenu( FileEntry *entry );
+  void startLVPopUpAction( AGMessage *msg );
 };
 
 class NMFieldListViewDND:public FieldListViewDND
