@@ -1063,7 +1063,7 @@ int Path2OSideOp::run( WPUContext *wpu, ActionMessage *msg )
   Lister *l1;
   ListerMode *lm1;
   NormalMode *nm1;
-  char *dir=NULL;
+  const char *dir=NULL;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
