@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: normalops.h,v 1.12 2004/10/27 21:08:15 ralf Exp $ */
+/* $Id: normalops.h,v 1.13 2005/10/19 18:03:40 ralf Exp $ */
 
 #ifndef NORMALOPS_H
 #define NORMALOPS_H
@@ -42,7 +42,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  virtual int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
   virtual bool save(Datei *);
 
@@ -67,7 +67,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  virtual int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 protected:
   static const char *name;
@@ -88,7 +88,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
   virtual bool save(Datei *);
   
@@ -124,7 +124,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  virtual int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
   
   bool requestfilter();
@@ -146,7 +146,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  virtual int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 protected:
   static const char *name;
@@ -167,7 +167,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  virtual int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
   virtual bool save(Datei *);
   
