@@ -331,12 +331,22 @@ OwnOp::configure()
   ac1_3->setMaxSpace( 0 );
   ac1_3->setBorderWidth( 0 );
 
-  ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 337 ), 1 ), 0, 0, cfix );
+  Text *view_text = (Text*)ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 337 ), 1 ), 0, 0, cfix );
   ac1_3->setMinWidth( 5, 1, 0 );
   ac1_3->setMaxWidth( 5, 1, 0 );
   comreqb2 = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 458 ), 1, 0, 0 ), 2, 0, cfix );
   sg[1] = (StringGadget*)ac1_3->add( new StringGadget( aguix, 0, 0, 100, view_str, 0 ), 3, 0, cincw );
   
+  if ( cyb->getSelectedOption() == 3 ) {
+      sg[1]->show();
+      comreqb2->show();
+      view_text->show();
+  } else {
+      sg[1]->hide();
+      comreqb2->hide();
+      view_text->hide();
+  }
+  
   AContainer *ac1_4 = ac1->add( new AContainer( win, 2, 1 ), 0, 8 );
   ac1_4->setMinSpace( 5 );
   ac1_4->setMaxSpace( -1 );
@@ -463,6 +473,19 @@ OwnOp::configure()
             }
           }
 	  break;
+        case AG_CYCLEBUTTONCLICKED:
+            if ( msg->cyclebutton.cyclebutton == cyb ) {
+                if ( cyb->getSelectedOption() == 3 ) {
+                    sg[1]->show();
+                    comreqb2->show();
+                    view_text->show();
+                } else {
+                    sg[1]->hide();
+                    comreqb2->hide();
+                    view_text->hide();
+                }
+            }
+            break;
       }
       aguix->ReplyMessage(msg);
     }
