@@ -24,7 +24,7 @@
 
 #include "wdefines.h"
 #include <aguix/lowlevelfunc.h>
-#include <aguix/util.h>
+#include "simplelist.hh"
 #include <aguix/mutex.h>
 #include <aguix/condvar.h>
 
