@@ -80,10 +80,10 @@ ScrollListerOp::save(Datei *fh)
   if ( fh == NULL ) return false;
   switch(dir) {
     case SCROLLLISTEROP_RIGHT:
-      WConfig::configPutPair( fh, "mode", "right" );
+      fh->configPutPair( "mode", "right" );
       break;
     default:
-      WConfig::configPutPair( fh, "mode", "left" );
+      fh->configPutPair( "mode", "left" );
       break;
   }
   return true;
