@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: searchentryop.h,v 1.8 2004/10/27 21:08:58 ralf Exp $ */
+/* $Id: searchentryop.h,v 1.10 2005/11/22 20:22:33 ralf Exp $ */
 
 #ifndef SEARCHENTRYOP_H
 #define SEARCHENTRYOP_H
@@ -40,15 +40,16 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
   virtual bool save(Datei*);
   void setIgnoreCase( bool );
+  void setReverseSearch( bool );
   virtual int configure();
 protected:
   static const char *name;
   // Infos to save
-  bool ignore_case;
+  bool ignore_case, reverse_search;
 
   // temp variables
   Lister *startlister;
