@@ -29,6 +29,7 @@
 #include "fileviewer.hh"
 #include "flagreplacer.hh"
 #include <aguix/acontainerbb.h>
+#include <typeinfo>
 
 const char *SearchOp::name = "SearchOp";
 std::list<SearchOp::ResultStore*> SearchOp::_stored_results;
@@ -1013,7 +1014,8 @@ void SearchOp::viewResult()
 
       bool old_sln = FileViewer::getShowLineNumbers();
       FileViewer::setShowLineNumbers( true );
-      FileViewer::view( l, r.getLineNr(), true );
+      FileViewer fv;
+      fv.view( l, r.getLineNr(), true );
       FileViewer::setShowLineNumbers( old_sln );
     }
   }
