@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: showdircacheop.h,v 1.5 2004/10/27 21:09:15 ralf Exp $ */
+/* $Id: showdircacheop.h,v 1.6 2005/10/19 18:00:10 ralf Exp $ */
 
 #ifndef SHOWDIRCACHEOP_H
 #define SHOWDIRCACHEOP_H
@@ -42,7 +42,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 
   static const char *name;
