@@ -253,13 +253,12 @@ StartProgOp::normalmodestartprog( ActionMessage *am )
       List *l = ft->getDoubleClickActions();
       if ( l != NULL ) {
 	ActionMessage amsg( am->getWorker() );
-	amsg.flags = ft->getDoubleClickActionsGF();
 	
 	amsg.mode = amsg.AM_MODE_SPECIAL;
 	
 	amsg.setFE( tfe );
 	amsg.filetype = ft;
-	amsg.getActionList = DoubleClickAction::getActionList;
+        amsg.m_action_descr = RefCount<ActionDescr>( new DoubleClickAction::DoubleClickActionDescr() );
 	am->getWorker()->interpret( l, &amsg );
       }
     }
