@@ -22,7 +22,6 @@
 #include "wcfiletype.hh"
 #include <aguix/aguix.h>
 #include <aguix/util.h>
-#include "wcglobalflags.hh"
 #include "datei.h"
 #include "functionproto.h"
 #include "simplelist.hh"
@@ -42,11 +41,6 @@ WCFiletype::WCFiletype()
   showaction=new List();
   rawshowaction=new List();
   for(i=0;i<10;i++) useraction[i]=new List();
-  dndactiongf=new WCGlobalFlags();
-  doubleclickactiongf=new WCGlobalFlags();
-  showactiongf=new WCGlobalFlags();
-  rawshowactiongf=new WCGlobalFlags();
-  for(i=0;i<10;i++) useractiongf[i]=new WCGlobalFlags();
   internID = NORMALTYPE;
 
   patternIgnoreCase = false;
@@ -100,11 +94,15 @@ WCFiletype::~WCFiletype()
   delete showaction;
   delete rawshowaction;
   for(i=0;i<10;i++) delete useraction[i];
-  delete dndactiongf;
-  delete doubleclickactiongf;
-  delete showactiongf;
-  delete rawshowactiongf;
-  for(i=0;i<10;i++) delete useractiongf[i];
+
+  std::map<std::string, List *>::iterator it1;
+
+  for ( it1 = customaction.begin();
+        it1 != customaction.end();
+        it1++ ) {
+      freecoms( it1->second );
+      delete it1->second;
+  }
 
   if ( extCond != NULL ) _freesafe( extCond );
 
@@ -134,11 +132,15 @@ WCFiletype *WCFiletype::duplicate() const
   tft->setShowActions(showaction);
   tft->setRawShowActions(rawshowaction);
   for(i=0;i<10;i++) tft->setUserActions(i,useraction[i]);
-  tft->setDNDActionsGF(dndactiongf);
-  tft->setDoubleClickActionsGF(doubleclickactiongf);
-  tft->setShowActionsGF(showactiongf);
-  tft->setRawShowActionsGF(rawshowactiongf);
-  for(i=0;i<10;i++) tft->setUserActionsGF(i,useractiongf[i]);
+
+  std::map<std::string, List *>::const_iterator it2;
+
+  for ( it2 = customaction.begin();
+        it2 != customaction.end();
+        it2++ ) {
+      tft->setCustomActions( it2->first, it2->second );
+  }
+
   tft->setinternID(internID);
   tft->setPatternIgnoreCase( patternIgnoreCase );
   tft->setPatternUseRegExp( patternUseRegExp );
@@ -350,63 +352,6 @@ void WCFiletype::addComUserAction( int i, const FunctionProto * fp )
   useraction[i]->addElement( fp->duplicate() );
 }
 
-WCGlobalFlags *WCFiletype::getDNDActionsGF()
-{
-  return dndactiongf;
-}
-
-WCGlobalFlags *WCFiletype::getDoubleClickActionsGF()
-{
-  return doubleclickactiongf;
-}
-
-WCGlobalFlags *WCFiletype::getShowActionsGF()
-{
-  return showactiongf;
-}
-
-WCGlobalFlags *WCFiletype::getRawShowActionsGF()
-{
-  return rawshowactiongf;
-}
-
-WCGlobalFlags *WCFiletype::getUserActionsGF(int index2)
-{
-  if((index2<0)||(index2>9)) return NULL;
-  return useractiongf[index2];
-}
-
-void WCFiletype::setDNDActionsGF(WCGlobalFlags *nf)
-{
-  if(nf==NULL) dndactiongf->setFlags(0);
-  else dndactiongf->setFlags(nf->getFlags());
-}
-
-void WCFiletype::setDoubleClickActionsGF(WCGlobalFlags *nf)
-{
-  if(nf==NULL) doubleclickactiongf->setFlags(0);
-  else doubleclickactiongf->setFlags(nf->getFlags());
-}
-
-void WCFiletype::setShowActionsGF(WCGlobalFlags *nf)
-{
-  if(nf==NULL) showactiongf->setFlags(0);
-  else showactiongf->setFlags(nf->getFlags());
-}
-
-void WCFiletype::setRawShowActionsGF(WCGlobalFlags *nf)
-{
-  if(nf==NULL) rawshowactiongf->setFlags(0);
-  else rawshowactiongf->setFlags(nf->getFlags());
-}
-
-void WCFiletype::setUserActionsGF(int index2,WCGlobalFlags *nf)
-{
-  if((index2<0)||(index2>9)) return;
-  if(nf==NULL) useractiongf[index2]->setFlags(0);
-  else useractiongf[index2]->setFlags(nf->getFlags());
-}
-
 void WCFiletype::setPatternIgnoreCase( bool nv )
 {
 #ifdef HAVE_REGEX
@@ -758,80 +703,95 @@ bool WCFiletype::save(Datei *fh) const
 
   fh->configPutPairString( "extcond", extCond );
   fh->configPutPairBool( "useextcond", useExtCond );
-  //TODO: Aus Platzgruenden nur die nicht-leeren speichern?
-  //      Aber was ist, wenn es mal Flags gibt und der User trotz
-  //      leerer Liste (wo ja dann flags keinen Einflu haben)
-  //      etwas auswhlt, sollte dann trotzdem gespeichert werden
+
   fh->configOpenSection( "ftcommands" );
 
-  fh->configOpenSection( "dnd" );
-  int id = dndaction->initEnum();
-  FunctionProto *f1 = (FunctionProto*)dndaction->getFirstElement( id );
-  while ( f1 != NULL ) {
-    FunctionProto::presave( fh, f1 );
-    f1 = (FunctionProto*)dndaction->getNextElement( id );
-  }
-  dndaction->closeEnum( id );
-  fh->configOpenSection( "flags" );
-  dndactiongf->save( fh );
-  fh->configCloseSection(); //flags
-  fh->configCloseSection(); //dnd
+  int id;
+  FunctionProto *f1;
 
-  fh->configOpenSection( "doubleclick" );
-  id = doubleclickaction->initEnum();
-  f1 = (FunctionProto*)doubleclickaction->getFirstElement( id );
-  while ( f1 != NULL ) {
-    FunctionProto::presave( fh, f1 );
-    f1 = (FunctionProto*)doubleclickaction->getNextElement( id );
+  if ( dndaction->size() > 0 ) {
+      fh->configOpenSection( "dnd" );
+      id = dndaction->initEnum();
+      f1 = (FunctionProto*)dndaction->getFirstElement( id );
+      while ( f1 != NULL ) {
+          FunctionProto::presave( fh, f1 );
+          f1 = (FunctionProto*)dndaction->getNextElement( id );
+      }
+      dndaction->closeEnum( id );
+      fh->configCloseSection(); //dnd
   }
-  doubleclickaction->closeEnum( id );
-  fh->configOpenSection( "flags" );
-  doubleclickactiongf->save( fh );
-  fh->configCloseSection(); //flags
-  fh->configCloseSection(); //doubleclick
 
-  fh->configOpenSection( "show" );
-  id = showaction->initEnum();
-  f1 = (FunctionProto*)showaction->getFirstElement( id );
-  while ( f1 != NULL ) {
-    FunctionProto::presave( fh, f1 );
-    f1 = (FunctionProto*)showaction->getNextElement( id );
+  if ( doubleclickaction->size() > 0 ) {
+      fh->configOpenSection( "doubleclick" );
+      id = doubleclickaction->initEnum();
+      f1 = (FunctionProto*)doubleclickaction->getFirstElement( id );
+      while ( f1 != NULL ) {
+          FunctionProto::presave( fh, f1 );
+          f1 = (FunctionProto*)doubleclickaction->getNextElement( id );
+      }
+      doubleclickaction->closeEnum( id );
+      fh->configCloseSection(); //doubleclick
   }
-  showaction->closeEnum( id );
-  fh->configOpenSection( "flags" );
-  showactiongf->save( fh );
-  fh->configCloseSection(); //flags
-  fh->configCloseSection(); //show
 
-  fh->configOpenSection( "rawshow" );
-  id = rawshowaction->initEnum();
-  f1 = (FunctionProto*)rawshowaction->getFirstElement( id );
-  while ( f1 != NULL ) {
-    FunctionProto::presave( fh, f1 );
-    f1 = (FunctionProto*)rawshowaction->getNextElement( id );
+  if ( showaction->size() > 0 ) {
+      fh->configOpenSection( "show" );
+      id = showaction->initEnum();
+      f1 = (FunctionProto*)showaction->getFirstElement( id );
+      while ( f1 != NULL ) {
+          FunctionProto::presave( fh, f1 );
+          f1 = (FunctionProto*)showaction->getNextElement( id );
+      }
+      showaction->closeEnum( id );
+      fh->configCloseSection(); //show
+  }
+  
+  if ( rawshowaction->size() > 0 ) {
+      fh->configOpenSection( "rawshow" );
+      id = rawshowaction->initEnum();
+      f1 = (FunctionProto*)rawshowaction->getFirstElement( id );
+      while ( f1 != NULL ) {
+          FunctionProto::presave( fh, f1 );
+          f1 = (FunctionProto*)rawshowaction->getNextElement( id );
+      }
+      rawshowaction->closeEnum( id );
+      fh->configCloseSection(); //rawshow
   }
-  rawshowaction->closeEnum( id );
-  fh->configOpenSection( "flags" );
-  rawshowactiongf->save( fh );
-  fh->configCloseSection(); //flags
-  fh->configCloseSection(); //rawshow
 
   for ( i = 0; i < 10; i++ ) {
-    sprintf( buf, "%d", i );
-    str1 = "user ";
-    str1 += buf;
-    fh->configOpenSection( str1.c_str() );
-    id = useraction[i]->initEnum();
-    f1 = (FunctionProto*)useraction[i]->getFirstElement( id );
-    while ( f1 != NULL ) {
-      FunctionProto::presave( fh, f1 );
-      f1 = (FunctionProto*)useraction[i]->getNextElement( id );
-    }
-    useraction[i]->closeEnum( id );
-    fh->configOpenSection( "flags" );
-    useractiongf[i]->save( fh );
-    fh->configCloseSection(); //flags
-    fh->configCloseSection(); //user x
+      if ( useraction[i]->size() > 0 ) {
+          sprintf( buf, "%d", i );
+          str1 = "user ";
+          str1 += buf;
+          fh->configOpenSection( str1.c_str() );
+          id = useraction[i]->initEnum();
+          f1 = (FunctionProto*)useraction[i]->getFirstElement( id );
+          while ( f1 != NULL ) {
+              FunctionProto::presave( fh, f1 );
+              f1 = (FunctionProto*)useraction[i]->getNextElement( id );
+          }
+          useraction[i]->closeEnum( id );
+          fh->configCloseSection(); //user x
+      }
+  }
+
+  std::map<std::string, List *>::const_iterator it2;
+
+  for ( it2 = customaction.begin();
+        it2 != customaction.end();
+        it2++ ) {
+      fh->configOpenSection( "customaction" );
+      fh->configPutPairString( "name", it2->first.c_str() );
+
+      fh->configOpenSection( "commands" );
+      id = it2->second->initEnum();
+      f1 = (FunctionProto*)it2->second->getFirstElement( id );
+      while ( f1 != NULL ) {
+          FunctionProto::presave( fh, f1 );
+          f1 = (FunctionProto*)it2->second->getNextElement( id );
+      }
+      it2->second->closeEnum( id );
+      fh->configCloseSection(); //commands
+      fh->configCloseSection(); //customaction
   }
 
   fh->configCloseSection(); //ftcommands
@@ -875,3 +835,92 @@ int WCFiletype::getNameLen() const
 {
   return namelen;
 }
+
+void WCFiletype::fillNamesOfCustomActions( bool recursive, std::list<std::string> &names )
+{
+    //TODO consider only lists with content
+    
+    std::map<std::string,List*>::iterator it1;
+    
+    //TODO iterate through names and check existence
+    for ( it1 = customaction.begin(); it1 != customaction.end(); it1++ ) {
+        names.push_back( it1->first );
+    }
+    
+    if ( recursive == true && parentType != NULL ) {
+        parentType->fillNamesOfCustomActions( recursive, names );
+    }
+}
+
+List *WCFiletype::getActionList( bool recursive, const ActionDescr &descr )
+{
+    List *res_list = NULL;
+    
+    res_list = descr.get_action_list( this );
+    if ( recursive == true && getParentType() != NULL &&
+         ( res_list == NULL || res_list->size() < 1 ) ) {
+        res_list = getParentType()->getActionList( recursive, descr );
+    }
+    return res_list;
+}
+
+List *WCFiletype::getCustomActions( const std::string &customname )
+{
+    if ( customaction.count( customname ) > 0 ) {
+        return customaction[customname];
+    }
+    return NULL;
+}
+
+void WCFiletype::setCustomActions( const std::string &customname, List *nua )
+{
+    if ( nua == NULL ) return;
+
+    if ( customaction.count( customname ) > 0 ) {
+        freecoms( customaction[customname] );
+    } else {
+        customaction[customname] = new List();
+    }
+    FunctionProto *fp;
+    int id = nua->initEnum();
+    fp = (FunctionProto*)nua->getFirstElement( id );
+    while ( fp != NULL ) {
+        customaction[customname]->addElement( fp->duplicate() );
+        fp = (FunctionProto*)nua->getNextElement( id );
+    }
+    nua->closeEnum( id );
+}
+
+void WCFiletype::addComCustomAction( const std::string &customname, const FunctionProto *fp )
+{
+    if ( fp == NULL ) return;
+ 
+    if ( customaction.count( customname ) > 0 ) {
+        freecoms( customaction[customname] );
+    } else {
+        customaction[customname] = new List();
+    }
+    customaction[customname]->addElement( fp->duplicate() );
+}
+
+void WCFiletype::removeCustomAction( const std::string &customname )
+{
+    if ( customaction.count( customname ) > 0 ) {
+        freecoms( customaction[customname] );
+	delete customaction[customname];
+	customaction.erase( customname );
+    }
+}
+
+void WCFiletype::clearCustomActions()
+{
+    std::map<std::string, List *>::iterator it1;
+    
+    for ( it1 = customaction.begin();
+	  it1 != customaction.end();
+	  it1++ ) {
+	freecoms( it1->second );
+	delete it1->second;
+    }
+    customaction.clear();
+}
