@@ -1,6 +1,6 @@
 /* wdefines.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: wdefines.h,v 1.37 2004/10/27 21:09:54 ralf Exp $ */
+/* $Id: wdefines.h,v 1.39 2005/03/14 22:15:11 ralf Exp $ */
 
 #ifndef WDEFINES_H
 #define WDEFINES_H
@@ -30,6 +30,14 @@
 
 #include "worker_lfs.h"
 
+#ifdef HAVE_AVFS
+extern "C" {
+#  include <virtual.h>
+}
+#endif
+
+#include "worker_filefunc.h"
+
 /* this following include isn't really needed at all
  * but the streambuf in (some?) stl implementations
  * undefing open/close (for whatever reason)
@@ -98,10 +106,6 @@
 #define OUTPUT_BIN "xmessage -file %s"
 #define TERMINAL_BIN "xterm -e %s"
 
-#if 0  // for filetype checking with file
-#define FILE_COMMAND "file -b %s"
-#endif
-
 #ifndef LINUX
   #ifndef ARG_MAX
     #ifdef _POSIX_ARG_MAX
