@@ -79,8 +79,8 @@ Worker::Worker(int targc,char **targv)
 
   workerInstances++;
   if ( aguix == NULL ) {
-    aguix = new AGUIX();
-    aguix->initX( targc, targv, "Worker" );
+    aguix = new AGUIX( targc, targv, "Worker" );
+    aguix->initX();
   }
   mainwin=NULL;
   aboutb=NULL;
@@ -817,8 +817,15 @@ void Worker::setupMainWin()
   delete msg;
 
   FieldListView::changeButtonFunction( FieldListView::SELECT_BUTTON, wconfig->getMouseSelectButton() );
-  FieldListView::changeButtonFunction( FieldListView::ACTIVATE_BUTTON, wconfig->getMouseActivateButton() );
-  FieldListView::changeButtonFunction( FieldListView::SCROLL_BUTTON, wconfig->getMouseScrollButton() );
+  FieldListView::changeButtonFunction( FieldListView::ACTIVATE_BUTTON,
+                                       wconfig->getMouseActivateButton(),
+                                       wconfig->getMouseActivateMod() );
+  FieldListView::changeButtonFunction( FieldListView::SCROLL_BUTTON,
+                                       wconfig->getMouseScrollButton(),
+                                       wconfig->getMouseScrollMod() );
+  FieldListView::changeButtonFunction( FieldListView::ENTRY_PRESSED_MSG_BUTTON,
+                                       wconfig->getMouseContextButton(),
+                                       wconfig->getMouseContextMod() );
   FieldListView::changeSelectMode( ( wconfig->getMouseSelectMethod() == WConfig::MOUSECONF_ALT_MODE ) ? FieldListView::MOUSE_SELECT_ALT : FieldListView::MOUSE_SELECT_NORMAL );
 
   mainwin->show();
@@ -1189,12 +1196,10 @@ int Worker::activateShortkey(AGMessage *msg)
     if ( lastkey == 0 ) {
       if ( findkey( msg->key.key, keystate, &b1, &hk1, &p1 ) > 0 ) {
         if ( b1 != NULL ) {
-          amsg.flags = b1->getComsGF();
           amsg.mode = amsg.AM_MODE_NORMAL;
           interpret( b1->getComs(), &amsg );
           found = true;
         } else if ( hk1 != NULL ) {
-          amsg.flags = hk1->getComsGF();
           amsg.mode = amsg.AM_MODE_NORMAL;
           interpret( hk1->getComs(), &amsg );
           found = true;
@@ -1209,12 +1214,10 @@ int Worker::activateShortkey(AGMessage *msg)
     } else {
       if ( findkey( lastkey, lastmod, msg->key.key, keystate, &b1, &hk1, &p1 ) > 0 ) {
         if ( b1 != NULL ) {
-          amsg.flags = b1->getComsGF();
           amsg.mode = amsg.AM_MODE_NORMAL;
           interpret( b1->getComs(), &amsg );
           found = true;
         } else if ( hk1 != NULL ) {
-          amsg.flags = hk1->getComsGF();
           amsg.mode = amsg.AM_MODE_NORMAL;
           interpret( hk1->getComs(), &amsg );
           found = true;
@@ -1227,12 +1230,10 @@ int Worker::activateShortkey(AGMessage *msg)
       } else {
         if ( findkey( msg->key.key, keystate, &b1, &hk1, &p1 ) > 0 ) {
           if ( b1 != NULL ) {
-            amsg.flags = b1->getComsGF();
             amsg.mode = amsg.AM_MODE_NORMAL;
             interpret( b1->getComs(), &amsg );
             found = true;
           } else if ( hk1 != NULL ) {
-            amsg.flags = hk1->getComsGF();
             amsg.mode = amsg.AM_MODE_NORMAL;
             interpret( hk1->getComs(), &amsg );
             found = true;
@@ -1281,7 +1282,6 @@ void Worker::activateButton(int i,int j,int m)
   b1=(WCButton*)l1->getElementAt(id,pos);
   if(b1!=NULL) {
     if(b1->getCheck()==true) {
-      amsg.flags=b1->getComsGF();
       amsg.mode=amsg.AM_MODE_NORMAL;
       interpret(b1->getComs(),&amsg);
     }
@@ -1757,18 +1757,18 @@ Requester *Worker::getRequester()
 
 void Worker::activateShortkeyFromList()
 {
-  // 1.alle mglichen Shortkeys finden und in eine Liste packen
+  // 1.alle moeglichen Shortkeys finden und in eine Liste packen
   // 2.Diese Liste sortieren
   //   Hotkey<Button<Pfad   (Hotkey zuerst, weil man die am schnellsten vergisst)
   //   Unter gleichem Typ einfach nach Name case-ins sortieren
   // 3.Aus dieser Liste wird nun das LV erstellt:
   //   <Typ>:<Name>   <Shortkey>
   //   Dabei <Typ>:<Name> maximieren, damit Shortkey ganz rechts steht
-  //   Achtung: Vielleicht fr das LV den Font des linken LVs nehmen, falls der User doch mal
+  //   Achtung: Vielleicht fuer das LV den Font des linken LVs nehmen, falls der User doch mal
   //            einen nichtpro. Font einstellt, dann klappt das auch hier
   // 4.lv Horizontal maximieren
   // 5.lv->takeFocus(), damit man das ganze auch einfach mit der Tastatur benutzen kann
-  // 6.der User whlt nun aus
+  // 6.der User waehlt nun aus
   // 7.Bei Abbruch nichts machen
   // 8.Bei Okay/Return/Doppelklick dann diesen Shortkey aktivieren
 
@@ -2043,10 +2043,8 @@ void Worker::activateShortkeyFromList()
     if(sk1!=NULL) {
       amsg.mode=amsg.AM_MODE_NORMAL;
       if(sk1->h!=NULL) {
-        amsg.flags=sk1->h->getComsGF();
         interpret(sk1->h->getComs(),&amsg);
       } else if(sk1->b!=NULL) {
-        amsg.flags=sk1->b->getComsGF();
         interpret(sk1->b->getComs(),&amsg);
       } else if(sk1->p!=NULL) {
         setPath(wconfig->getPaths()->getIndex(sk1->p));
@@ -2078,12 +2076,12 @@ int Worker::shortkeysort(void*p1,void*p2)
 
   // Hotkey ist kleiner als Button & Pfad
   if((sk1->h!=NULL)&&(sk2->h==NULL)) return -1;
-  // Button is kleiner Pfad, aber grer als Hotkey
+  // Button is kleiner Pfad, aber groesser als Hotkey
   if(sk1->b!=NULL) {
     if(sk2->h!=NULL) return 1;
     if(sk2->p!=NULL) return -1;
   }
-  // Pfad ist grer als Hotkey & Button
+  // Pfad ist groesser als Hotkey & Button
   if((sk1->p!=NULL)&&(sk2->p==NULL)) return 1;
   
   // Ab hier sind beide vom gleichen Typ
