@@ -180,6 +180,12 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 51:
       fpr = new DirBookmarkOp();
       break;
+    case 52:
+      fpr = new OpenContextMenuOp();
+      break;
+    case 53:
+      fpr = new RunCustomAction();
+      break;
     default:
       fpr=new DNDAction();
   }
@@ -241,6 +247,8 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( InternalViewOp::name ) == true ) type = 49;
   else if ( fpr->isName( SearchOp::name ) == true ) type = 50;
   else if ( fpr->isName( DirBookmarkOp::name ) == true ) type = 51;
+  else if ( fpr->isName( OpenContextMenuOp::name ) == true ) type = 52;
+  else if ( fpr->isName( RunCustomAction::name ) == true ) type = 53;
   return type;
 }
 
