@@ -54,6 +54,8 @@
 #include "intviewop.h"
 #include "searchop.hh"
 #include "dirbookmarkop.hh"
+#include "opencontextmenuop.hh"
+#include "run_custom_action.hh"
 
 #include "listermode.h"
 #include "normalmode.h"
