@@ -24,8 +24,8 @@
 #include "worker.h"
 #include <aguix/utf8.hh>
 
-#define CATENTRY 768
-#define CATCOMENTRY 52
+#define CATENTRY 780
+#define CATCOMENTRY 54
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -117,7 +117,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[61]=dupstring( "Choose shortcut" );
   catalog[62]=dupstring( "Delete shortcut" );
   catalog[63]=dupstring( "A path named %s already uses this shortcut!|Click Okay to remove the reference to this shortcut|from the path and use it here instead" );
-  catalog[64]=dupstring( "Flags" );
+  catalog[64]=dupstring( "" );
   catalog[65]=dupstring( "A hotkey named %s already uses this shortcut!|Click Okay to remove the reference to this shortcut|from the hotkey and use it here instead" );
   catalog[66]=dupstring( "Please press the key for the shortcut!" );
   catalog[67]=dupstring( "The destination directory %s doesn't exists!" );
@@ -868,6 +868,18 @@ match any font." );
   catalog[765]=dupstring( "Read partial file" );
   catalog[766]=dupstring( "Read complete file" );
   catalog[767]=dupstring( "Read complete file but disable wrapping" );
+  catalog[768]=dupstring( "Activate action" );
+  catalog[769]=dupstring( "Without modifier key" );
+  catalog[770]=dupstring( "Shift" );
+  catalog[771]=dupstring( "Ctrl" );
+  catalog[772]=dupstring( "Mod1" );
+  catalog[773]=dupstring( "Context menu:" );
+  catalog[774]=dupstring( "Name of custom action" );
+  catalog[775]=dupstring( "Enter new action name:" );
+  catalog[776]=dupstring( "Or select an existing name:" );
+  catalog[777]=dupstring( "New action" );
+  catalog[778]=dupstring( "Remove action" );
+  catalog[779]=dupstring( "Enter name of the action to activate:" );
 
 //  catalog[]=dupstring( "" );
   
@@ -923,6 +935,8 @@ match any font." );
   catalogcom[49]=dupstring( "Internal text viewer" );
   catalogcom[50]=dupstring( "Search" );
   catalogcom[51]=dupstring( "Directory bookmarks" );
+  catalogcom[52]=dupstring( "Open context menu" );
+  catalogcom[53]=dupstring( "Run custom action" );
   
   catalogflag[0]=dupstring( "Stringrequester" );
   catalogflag[1]=dupstring( "path" );
